# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .api_error import ApiError
    from .api_version_enum import ApiVersionEnum
    from .array_strategy import ArrayStrategy
    from .array_strategy_type import ArrayStrategyType
    from .batch_processor_run import BatchProcessorRun
    from .batch_processor_run_metrics import BatchProcessorRunMetrics
    from .batch_processor_run_options import BatchProcessorRunOptions
    from .batch_processor_run_source import BatchProcessorRunSource
    from .batch_processor_run_status import BatchProcessorRunStatus
    from .batch_run import BatchRun
    from .batch_run_entity import (
        BatchRunEntity,
        BatchRunEntity_Classifier,
        BatchRunEntity_Extractor,
        BatchRunEntity_Splitter,
    )
    from .batch_run_entity_version import (
        BatchRunEntityVersion,
        BatchRunEntityVersion_ClassifierVersion,
        BatchRunEntityVersion_ExtractorVersion,
        BatchRunEntityVersion_SplitterVersion,
    )
    from .batch_run_metrics import BatchRunMetrics
    from .batch_run_status import BatchRunStatus
    from .block import Block
    from .block_details import BlockDetails
    from .block_metadata import BlockMetadata
    from .block_metadata_page import BlockMetadataPage
    from .block_polygon_item import BlockPolygonItem
    from .block_type import BlockType
    from .bounding_box import BoundingBox
    from .chunk import Chunk
    from .chunk_metadata import ChunkMetadata
    from .chunk_metadata_page_range import ChunkMetadataPageRange
    from .chunk_type import ChunkType
    from .citation import Citation
    from .citation_page import CitationPage
    from .classification import Classification
    from .classifications import Classifications
    from .classifier import Classifier
    from .classifier_created_webhook_event import ClassifierCreatedWebhookEvent
    from .classifier_deleted_webhook_event import ClassifierDeletedWebhookEvent
    from .classifier_draft_updated_webhook_event import ClassifierDraftUpdatedWebhookEvent
    from .classifier_summary import ClassifierSummary
    from .classifier_updated_webhook_event import ClassifierUpdatedWebhookEvent
    from .classifier_version import ClassifierVersion
    from .classifier_version_published_webhook_event import ClassifierVersionPublishedWebhookEvent
    from .classifier_version_summary import ClassifierVersionSummary
    from .classify_advanced_options import ClassifyAdvancedOptions
    from .classify_advanced_options_context import ClassifyAdvancedOptionsContext
    from .classify_base_processor import ClassifyBaseProcessor
    from .classify_config import ClassifyConfig
    from .classify_output import ClassifyOutput
    from .classify_override_config import ClassifyOverrideConfig
    from .classify_request_classifier import ClassifyRequestClassifier
    from .classify_request_file import ClassifyRequestFile
    from .classify_result import ClassifyResult
    from .classify_run import ClassifyRun
    from .classify_run_failed_webhook_event import ClassifyRunFailedWebhookEvent
    from .classify_run_processed_webhook_event import ClassifyRunProcessedWebhookEvent
    from .classify_run_summary import ClassifyRunSummary
    from .classify_step_run import ClassifyStepRun
    from .classify_step_run_step import ClassifyStepRunStep
    from .conditional_extract_result import ConditionalExtractResult
    from .conditional_extract_step_run import ConditionalExtractStepRun
    from .conditional_extract_step_run_step import ConditionalExtractStepRunStep
    from .created_at import CreatedAt
    from .edit_bounding_box import EditBoundingBox
    from .edit_config import EditConfig
    from .edit_config_advanced_options import EditConfigAdvancedOptions
    from .edit_json import EditJson
    from .edit_json_extend_edit_field_type import EditJsonExtendEditFieldType
    from .edit_object_json import EditObjectJson
    from .edit_request_file import EditRequestFile
    from .edit_root_json import EditRootJson
    from .edit_run import EditRun
    from .edit_run_failed_webhook_event import EditRunFailedWebhookEvent
    from .edit_run_metrics import EditRunMetrics
    from .edit_run_output import EditRunOutput
    from .edit_run_output_edited_file import EditRunOutputEditedFile
    from .edit_run_processed_webhook_event import EditRunProcessedWebhookEvent
    from .edit_run_status import EditRunStatus
    from .edit_text_options import EditTextOptions
    from .empty_block_details import EmptyBlockDetails
    from .enum import Enum
    from .enum_option import EnumOption
    from .evaluation_set import EvaluationSet
    from .evaluation_set_entity import (
        EvaluationSetEntity,
        EvaluationSetEntity_Classifier,
        EvaluationSetEntity_Extractor,
        EvaluationSetEntity_Splitter,
    )
    from .evaluation_set_item import EvaluationSetItem
    from .evaluation_set_item_summary import EvaluationSetItemSummary
    from .evaluation_set_run import EvaluationSetRun
    from .evaluation_set_run_entity import (
        EvaluationSetRunEntity,
        EvaluationSetRunEntity_Classifier,
        EvaluationSetRunEntity_Extractor,
        EvaluationSetRunEntity_Splitter,
    )
    from .evaluation_set_run_entity_version import (
        EvaluationSetRunEntityVersion,
        EvaluationSetRunEntityVersion_ClassifierVersion,
        EvaluationSetRunEntityVersion_ExtractorVersion,
        EvaluationSetRunEntityVersion_SplitterVersion,
    )
    from .evaluation_set_run_metrics import EvaluationSetRunMetrics
    from .evaluation_set_run_options import EvaluationSetRunOptions
    from .excel_sheet_range import ExcelSheetRange
    from .external_data_validation_result import ExternalDataValidationResult
    from .external_data_validation_result_response import ExternalDataValidationResultResponse
    from .external_data_validation_step_run import ExternalDataValidationStepRun
    from .external_data_validation_step_run_step import ExternalDataValidationStepRunStep
    from .extract_advanced_options import ExtractAdvancedOptions
    from .extract_advanced_options_array_citation_strategy import ExtractAdvancedOptionsArrayCitationStrategy
    from .extract_advanced_options_excel_sheet_selection_strategy import (
        ExtractAdvancedOptionsExcelSheetSelectionStrategy,
    )
    from .extract_advanced_options_review_agent import ExtractAdvancedOptionsReviewAgent
    from .extract_base_processor import ExtractBaseProcessor
    from .extract_chunking_options import ExtractChunkingOptions
    from .extract_chunking_options_chunk_selection_strategy import ExtractChunkingOptionsChunkSelectionStrategy
    from .extract_chunking_options_chunking_strategy import ExtractChunkingOptionsChunkingStrategy
    from .extract_config import ExtractConfig
    from .extract_config_json import ExtractConfigJson
    from .extract_config_legacy import ExtractConfigLegacy
    from .extract_config_legacy_base_processor import ExtractConfigLegacyBaseProcessor
    from .extract_output import ExtractOutput
    from .extract_output_edits import ExtractOutputEdits
    from .extract_output_json import ExtractOutputJson
    from .extract_output_legacy import ExtractOutputLegacy
    from .extract_output_metadata import ExtractOutputMetadata
    from .extract_output_metadata_value import ExtractOutputMetadataValue
    from .extract_override_config_json import ExtractOverrideConfigJson
    from .extract_request_extractor import ExtractRequestExtractor
    from .extract_request_file import ExtractRequestFile
    from .extract_result import ExtractResult
    from .extract_run import ExtractRun
    from .extract_run_failed_webhook_event import ExtractRunFailedWebhookEvent
    from .extract_run_processed_webhook_event import ExtractRunProcessedWebhookEvent
    from .extract_run_summary import ExtractRunSummary
    from .extract_step_run import ExtractStepRun
    from .extract_step_run_step import ExtractStepRunStep
    from .extraction_field import ExtractionField
    from .extraction_field_result import ExtractionFieldResult
    from .extraction_field_result_reference import ExtractionFieldResultReference
    from .extraction_field_result_reference_bounding_boxes_item import ExtractionFieldResultReferenceBoundingBoxesItem
    from .extraction_field_result_type import ExtractionFieldResultType
    from .extraction_field_type import ExtractionFieldType
    from .extractor import Extractor
    from .extractor_created_webhook_event import ExtractorCreatedWebhookEvent
    from .extractor_deleted_webhook_event import ExtractorDeletedWebhookEvent
    from .extractor_draft_updated_webhook_event import ExtractorDraftUpdatedWebhookEvent
    from .extractor_summary import ExtractorSummary
    from .extractor_updated_webhook_event import ExtractorUpdatedWebhookEvent
    from .extractor_version import ExtractorVersion
    from .extractor_version_published_webhook_event import ExtractorVersionPublishedWebhookEvent
    from .extractor_version_summary import ExtractorVersionSummary
    from .figure_details import FigureDetails
    from .figure_details_figure_type import FigureDetailsFigureType
    from .file import File
    from .file_contents import FileContents
    from .file_contents_pages_item import FileContentsPagesItem
    from .file_contents_sections_item import FileContentsSectionsItem
    from .file_contents_sheets_item import FileContentsSheetsItem
    from .file_from_id import FileFromId
    from .file_from_text import FileFromText
    from .file_from_url import FileFromUrl
    from .file_metadata import FileMetadata
    from .file_summary import FileSummary
    from .file_type import FileType
    from .insight import Insight
    from .json_object import JsonObject
    from .legacy_batch_processor_run import LegacyBatchProcessorRun
    from .legacy_batch_processor_run_metrics import LegacyBatchProcessorRunMetrics
    from .legacy_batch_processor_run_options import LegacyBatchProcessorRunOptions
    from .legacy_batch_processor_run_source import LegacyBatchProcessorRunSource
    from .legacy_batch_processor_run_status import LegacyBatchProcessorRunStatus
    from .legacy_classification import LegacyClassification
    from .legacy_classification_advanced_options import LegacyClassificationAdvancedOptions
    from .legacy_classification_advanced_options_context import LegacyClassificationAdvancedOptionsContext
    from .legacy_classification_config import LegacyClassificationConfig
    from .legacy_classification_config_base_processor import LegacyClassificationConfigBaseProcessor
    from .legacy_classifier_output import LegacyClassifierOutput
    from .legacy_document_processor_run_credits import LegacyDocumentProcessorRunCredits
    from .legacy_error import LegacyError
    from .legacy_extend_error import LegacyExtendError
    from .legacy_extract_chunking_options import LegacyExtractChunkingOptions
    from .legacy_extract_chunking_options_chunk_selection_strategy import (
        LegacyExtractChunkingOptionsChunkSelectionStrategy,
    )
    from .legacy_extract_chunking_options_chunking_strategy import LegacyExtractChunkingOptionsChunkingStrategy
    from .legacy_extraction_advanced_options import LegacyExtractionAdvancedOptions
    from .legacy_extraction_advanced_options_array_citation_strategy import (
        LegacyExtractionAdvancedOptionsArrayCitationStrategy,
    )
    from .legacy_extraction_advanced_options_excel_sheet_selection_strategy import (
        LegacyExtractionAdvancedOptionsExcelSheetSelectionStrategy,
    )
    from .legacy_extraction_advanced_options_review_agent import LegacyExtractionAdvancedOptionsReviewAgent
    from .legacy_extraction_config import LegacyExtractionConfig
    from .legacy_extraction_config_base_processor import LegacyExtractionConfigBaseProcessor
    from .legacy_extraction_field import LegacyExtractionField
    from .legacy_extraction_field_result import LegacyExtractionFieldResult
    from .legacy_extraction_field_result_type import LegacyExtractionFieldResultType
    from .legacy_extraction_field_type import LegacyExtractionFieldType
    from .legacy_extraction_output import LegacyExtractionOutput
    from .legacy_extraction_output_edits import LegacyExtractionOutputEdits
    from .legacy_fields_array_output import LegacyFieldsArrayOutput
    from .legacy_json_object import LegacyJsonObject
    from .legacy_json_output import LegacyJsonOutput
    from .legacy_json_output_metadata_value import LegacyJsonOutputMetadataValue
    from .legacy_json_output_metadata_value_citations_item import LegacyJsonOutputMetadataValueCitationsItem
    from .legacy_json_output_metadata_value_citations_item_polygon_item import (
        LegacyJsonOutputMetadataValueCitationsItemPolygonItem,
    )
    from .legacy_list_processors_processor import LegacyListProcessorsProcessor
    from .legacy_list_processors_processor_version import LegacyListProcessorsProcessorVersion
    from .legacy_list_processors_response import LegacyListProcessorsResponse
    from .legacy_max_page_size import LegacyMaxPageSize
    from .legacy_next_page_token import LegacyNextPageToken
    from .legacy_processor import LegacyProcessor
    from .legacy_processor_id import LegacyProcessorId
    from .legacy_processor_output import LegacyProcessorOutput
    from .legacy_processor_run import LegacyProcessorRun
    from .legacy_processor_run_config import (
        LegacyProcessorRunConfig,
        LegacyProcessorRunConfig_Classify,
        LegacyProcessorRunConfig_Extract,
        LegacyProcessorRunConfig_Splitter,
    )
    from .legacy_processor_run_file_input import LegacyProcessorRunFileInput
    from .legacy_processor_run_merged_processors_item import LegacyProcessorRunMergedProcessorsItem
    from .legacy_processor_run_summary import LegacyProcessorRunSummary
    from .legacy_processor_run_summary_type import LegacyProcessorRunSummaryType
    from .legacy_processor_run_type import LegacyProcessorRunType
    from .legacy_processor_status import LegacyProcessorStatus
    from .legacy_processor_type import LegacyProcessorType
    from .legacy_processor_version import LegacyProcessorVersion
    from .legacy_processor_version_config import (
        LegacyProcessorVersionConfig,
        LegacyProcessorVersionConfig_Classify,
        LegacyProcessorVersionConfig_Extract,
        LegacyProcessorVersionConfig_Splitter,
    )
    from .legacy_provided_classifier_output import LegacyProvidedClassifierOutput
    from .legacy_provided_extraction_field_result import LegacyProvidedExtractionFieldResult
    from .legacy_provided_extraction_field_result_type import LegacyProvidedExtractionFieldResultType
    from .legacy_provided_extraction_output import LegacyProvidedExtractionOutput
    from .legacy_provided_fields_array_output import LegacyProvidedFieldsArrayOutput
    from .legacy_provided_json_output import LegacyProvidedJsonOutput
    from .legacy_provided_processor_output import LegacyProvidedProcessorOutput
    from .legacy_provided_splitter_output import LegacyProvidedSplitterOutput
    from .legacy_provided_splitter_output_splits_item import LegacyProvidedSplitterOutputSplitsItem
    from .legacy_sort_by_enum import LegacySortByEnum
    from .legacy_sort_dir_enum import LegacySortDirEnum
    from .legacy_splitter_advanced_options import LegacySplitterAdvancedOptions
    from .legacy_splitter_advanced_options_split_method import LegacySplitterAdvancedOptionsSplitMethod
    from .legacy_splitter_config import LegacySplitterConfig
    from .legacy_splitter_config_base_processor import LegacySplitterConfigBaseProcessor
    from .legacy_splitter_output import LegacySplitterOutput
    from .legacy_splitter_output_splits_item import LegacySplitterOutputSplitsItem
    from .max_page_size import MaxPageSize
    from .merge_extract_result import MergeExtractResult
    from .merge_extract_result_merged_extractors_item import MergeExtractResultMergedExtractorsItem
    from .merge_extract_step_run import MergeExtractStepRun
    from .merge_extract_step_run_step import MergeExtractStepRunStep
    from .next_page_token import NextPageToken
    from .page_ranges import PageRanges
    from .page_ranges_item import PageRangesItem
    from .parent_split import ParentSplit
    from .parse_config import ParseConfig
    from .parse_config_advanced_options import ParseConfigAdvancedOptions
    from .parse_config_advanced_options_excel_parsing_mode import ParseConfigAdvancedOptionsExcelParsingMode
    from .parse_config_advanced_options_return_ocr import ParseConfigAdvancedOptionsReturnOcr
    from .parse_config_block_options import ParseConfigBlockOptions
    from .parse_config_block_options_figures import ParseConfigBlockOptionsFigures
    from .parse_config_block_options_tables import ParseConfigBlockOptionsTables
    from .parse_config_block_options_tables_agentic import ParseConfigBlockOptionsTablesAgentic
    from .parse_config_block_options_tables_target_format import ParseConfigBlockOptionsTablesTargetFormat
    from .parse_config_block_options_text import ParseConfigBlockOptionsText
    from .parse_config_block_options_text_agentic import ParseConfigBlockOptionsTextAgentic
    from .parse_config_chunking_strategy import ParseConfigChunkingStrategy
    from .parse_config_chunking_strategy_options import ParseConfigChunkingStrategyOptions
    from .parse_config_chunking_strategy_type import ParseConfigChunkingStrategyType
    from .parse_config_engine import ParseConfigEngine
    from .parse_config_target import ParseConfigTarget
    from .parse_request_file import ParseRequestFile
    from .parse_request_response_type import ParseRequestResponseType
    from .parse_result import ParseResult
    from .parse_run import ParseRun
    from .parse_run_failed_webhook_event import ParseRunFailedWebhookEvent
    from .parse_run_metrics import ParseRunMetrics
    from .parse_run_output import ParseRunOutput
    from .parse_run_output_ocr import ParseRunOutputOcr
    from .parse_run_output_ocr_words_item import ParseRunOutputOcrWordsItem
    from .parse_run_processed_webhook_event import ParseRunProcessedWebhookEvent
    from .parse_run_status import ParseRunStatus
    from .parse_run_status_enum import ParseRunStatusEnum
    from .parse_run_status_status import ParseRunStatusStatus
    from .parse_step_run import ParseStepRun
    from .parse_step_run_step import ParseStepRunStep
    from .polygon import Polygon
    from .processor_run_status import ProcessorRunStatus
    from .processor_version_string import ProcessorVersionString
    from .provided_classify_output import ProvidedClassifyOutput
    from .provided_extract_output import ProvidedExtractOutput
    from .provided_processor_output import ProvidedProcessorOutput
    from .provided_split_output import ProvidedSplitOutput
    from .provided_split_output_splits_item import ProvidedSplitOutputSplitsItem
    from .release_type import ReleaseType
    from .rule_validation_result import RuleValidationResult
    from .rule_validation_result_rules_item import RuleValidationResultRulesItem
    from .rule_validation_result_rules_item_failure_reason import RuleValidationResultRulesItemFailureReason
    from .rule_validation_step_run import RuleValidationStepRun
    from .rule_validation_step_run_step import RuleValidationStepRunStep
    from .run_metadata import RunMetadata
    from .run_priority import RunPriority
    from .run_secrets import RunSecrets
    from .run_source import RunSource
    from .run_source_id import RunSourceId
    from .run_usage import RunUsage
    from .sort_by import SortBy
    from .sort_dir import SortDir
    from .split_advanced_options import SplitAdvancedOptions
    from .split_advanced_options_split_method import SplitAdvancedOptionsSplitMethod
    from .split_base_processor import SplitBaseProcessor
    from .split_config import SplitConfig
    from .split_output import SplitOutput
    from .split_output_splits_item import SplitOutputSplitsItem
    from .split_override_config import SplitOverrideConfig
    from .split_request_file import SplitRequestFile
    from .split_request_splitter import SplitRequestSplitter
    from .split_result import SplitResult
    from .split_run import SplitRun
    from .split_run_failed_webhook_event import SplitRunFailedWebhookEvent
    from .split_run_processed_webhook_event import SplitRunProcessedWebhookEvent
    from .split_run_summary import SplitRunSummary
    from .split_step_run import SplitStepRun
    from .split_step_run_step import SplitStepRunStep
    from .splitter import Splitter
    from .splitter_created_webhook_event import SplitterCreatedWebhookEvent
    from .splitter_deleted_webhook_event import SplitterDeletedWebhookEvent
    from .splitter_draft_updated_webhook_event import SplitterDraftUpdatedWebhookEvent
    from .splitter_summary import SplitterSummary
    from .splitter_updated_webhook_event import SplitterUpdatedWebhookEvent
    from .splitter_version import SplitterVersion
    from .splitter_version_published_webhook_event import SplitterVersionPublishedWebhookEvent
    from .splitter_version_summary import SplitterVersionSummary
    from .step_run import StepRun
    from .step_run_base import StepRunBase
    from .step_run_base_status import StepRunBaseStatus
    from .table_cell_details import TableCellDetails
    from .table_details import TableDetails
    from .too_many_requests_error_body import TooManyRequestsErrorBody
    from .updated_at import UpdatedAt
    from .version_description import VersionDescription
    from .webhook_advanced_options import WebhookAdvancedOptions
    from .webhook_endpoint import WebhookEndpoint
    from .webhook_endpoint_create import WebhookEndpointCreate
    from .webhook_endpoint_event_type import WebhookEndpointEventType
    from .webhook_endpoint_status import WebhookEndpointStatus
    from .webhook_event import (
        WebhookEvent,
        WebhookEvent_ClassifierCreated,
        WebhookEvent_ClassifierDeleted,
        WebhookEvent_ClassifierDraftUpdated,
        WebhookEvent_ClassifierUpdated,
        WebhookEvent_ClassifierVersionPublished,
        WebhookEvent_ClassifyRunFailed,
        WebhookEvent_ClassifyRunProcessed,
        WebhookEvent_EditRunFailed,
        WebhookEvent_EditRunProcessed,
        WebhookEvent_ExtractRunFailed,
        WebhookEvent_ExtractRunProcessed,
        WebhookEvent_ExtractorCreated,
        WebhookEvent_ExtractorDeleted,
        WebhookEvent_ExtractorDraftUpdated,
        WebhookEvent_ExtractorUpdated,
        WebhookEvent_ExtractorVersionPublished,
        WebhookEvent_ParseRunFailed,
        WebhookEvent_ParseRunProcessed,
        WebhookEvent_SplitRunFailed,
        WebhookEvent_SplitRunProcessed,
        WebhookEvent_SplitterCreated,
        WebhookEvent_SplitterDeleted,
        WebhookEvent_SplitterDraftUpdated,
        WebhookEvent_SplitterUpdated,
        WebhookEvent_SplitterVersionPublished,
        WebhookEvent_WorkflowCreated,
        WebhookEvent_WorkflowDeleted,
        WebhookEvent_WorkflowDeployed,
        WebhookEvent_WorkflowRunCancelled,
        WebhookEvent_WorkflowRunCompleted,
        WebhookEvent_WorkflowRunFailed,
        WebhookEvent_WorkflowRunNeedsReview,
        WebhookEvent_WorkflowRunRejected,
        WebhookEvent_WorkflowRunStepRunProcessed,
    )
    from .webhook_payload_format import WebhookPayloadFormat
    from .webhook_payload_options import WebhookPayloadOptions
    from .webhook_subscription import WebhookSubscription
    from .webhook_subscription_event_type import WebhookSubscriptionEventType
    from .webhook_subscription_resource_type import WebhookSubscriptionResourceType
    from .workflow import Workflow
    from .workflow_created_webhook_event import WorkflowCreatedWebhookEvent
    from .workflow_deleted_webhook_event import WorkflowDeletedWebhookEvent
    from .workflow_deployed_webhook_event import WorkflowDeployedWebhookEvent
    from .workflow_reference import WorkflowReference
    from .workflow_run import WorkflowRun
    from .workflow_run_cancelled_webhook_event import WorkflowRunCancelledWebhookEvent
    from .workflow_run_completed_webhook_event import WorkflowRunCompletedWebhookEvent
    from .workflow_run_failed_webhook_event import WorkflowRunFailedWebhookEvent
    from .workflow_run_needs_review_webhook_event import WorkflowRunNeedsReviewWebhookEvent
    from .workflow_run_rejected_webhook_event import WorkflowRunRejectedWebhookEvent
    from .workflow_run_status import WorkflowRunStatus
    from .workflow_run_step_run_processed_webhook_event import WorkflowRunStepRunProcessedWebhookEvent
    from .workflow_run_summary import WorkflowRunSummary
    from .workflow_step_base import WorkflowStepBase
    from .workflow_summary import WorkflowSummary
    from .workflow_version import WorkflowVersion
    from .workflow_version_summary import WorkflowVersionSummary
_dynamic_imports: typing.Dict[str, str] = {
    "ApiError": ".api_error",
    "ApiVersionEnum": ".api_version_enum",
    "ArrayStrategy": ".array_strategy",
    "ArrayStrategyType": ".array_strategy_type",
    "BatchProcessorRun": ".batch_processor_run",
    "BatchProcessorRunMetrics": ".batch_processor_run_metrics",
    "BatchProcessorRunOptions": ".batch_processor_run_options",
    "BatchProcessorRunSource": ".batch_processor_run_source",
    "BatchProcessorRunStatus": ".batch_processor_run_status",
    "BatchRun": ".batch_run",
    "BatchRunEntity": ".batch_run_entity",
    "BatchRunEntityVersion": ".batch_run_entity_version",
    "BatchRunEntityVersion_ClassifierVersion": ".batch_run_entity_version",
    "BatchRunEntityVersion_ExtractorVersion": ".batch_run_entity_version",
    "BatchRunEntityVersion_SplitterVersion": ".batch_run_entity_version",
    "BatchRunEntity_Classifier": ".batch_run_entity",
    "BatchRunEntity_Extractor": ".batch_run_entity",
    "BatchRunEntity_Splitter": ".batch_run_entity",
    "BatchRunMetrics": ".batch_run_metrics",
    "BatchRunStatus": ".batch_run_status",
    "Block": ".block",
    "BlockDetails": ".block_details",
    "BlockMetadata": ".block_metadata",
    "BlockMetadataPage": ".block_metadata_page",
    "BlockPolygonItem": ".block_polygon_item",
    "BlockType": ".block_type",
    "BoundingBox": ".bounding_box",
    "Chunk": ".chunk",
    "ChunkMetadata": ".chunk_metadata",
    "ChunkMetadataPageRange": ".chunk_metadata_page_range",
    "ChunkType": ".chunk_type",
    "Citation": ".citation",
    "CitationPage": ".citation_page",
    "Classification": ".classification",
    "Classifications": ".classifications",
    "Classifier": ".classifier",
    "ClassifierCreatedWebhookEvent": ".classifier_created_webhook_event",
    "ClassifierDeletedWebhookEvent": ".classifier_deleted_webhook_event",
    "ClassifierDraftUpdatedWebhookEvent": ".classifier_draft_updated_webhook_event",
    "ClassifierSummary": ".classifier_summary",
    "ClassifierUpdatedWebhookEvent": ".classifier_updated_webhook_event",
    "ClassifierVersion": ".classifier_version",
    "ClassifierVersionPublishedWebhookEvent": ".classifier_version_published_webhook_event",
    "ClassifierVersionSummary": ".classifier_version_summary",
    "ClassifyAdvancedOptions": ".classify_advanced_options",
    "ClassifyAdvancedOptionsContext": ".classify_advanced_options_context",
    "ClassifyBaseProcessor": ".classify_base_processor",
    "ClassifyConfig": ".classify_config",
    "ClassifyOutput": ".classify_output",
    "ClassifyOverrideConfig": ".classify_override_config",
    "ClassifyRequestClassifier": ".classify_request_classifier",
    "ClassifyRequestFile": ".classify_request_file",
    "ClassifyResult": ".classify_result",
    "ClassifyRun": ".classify_run",
    "ClassifyRunFailedWebhookEvent": ".classify_run_failed_webhook_event",
    "ClassifyRunProcessedWebhookEvent": ".classify_run_processed_webhook_event",
    "ClassifyRunSummary": ".classify_run_summary",
    "ClassifyStepRun": ".classify_step_run",
    "ClassifyStepRunStep": ".classify_step_run_step",
    "ConditionalExtractResult": ".conditional_extract_result",
    "ConditionalExtractStepRun": ".conditional_extract_step_run",
    "ConditionalExtractStepRunStep": ".conditional_extract_step_run_step",
    "CreatedAt": ".created_at",
    "EditBoundingBox": ".edit_bounding_box",
    "EditConfig": ".edit_config",
    "EditConfigAdvancedOptions": ".edit_config_advanced_options",
    "EditJson": ".edit_json",
    "EditJsonExtendEditFieldType": ".edit_json_extend_edit_field_type",
    "EditObjectJson": ".edit_object_json",
    "EditRequestFile": ".edit_request_file",
    "EditRootJson": ".edit_root_json",
    "EditRun": ".edit_run",
    "EditRunFailedWebhookEvent": ".edit_run_failed_webhook_event",
    "EditRunMetrics": ".edit_run_metrics",
    "EditRunOutput": ".edit_run_output",
    "EditRunOutputEditedFile": ".edit_run_output_edited_file",
    "EditRunProcessedWebhookEvent": ".edit_run_processed_webhook_event",
    "EditRunStatus": ".edit_run_status",
    "EditTextOptions": ".edit_text_options",
    "EmptyBlockDetails": ".empty_block_details",
    "Enum": ".enum",
    "EnumOption": ".enum_option",
    "EvaluationSet": ".evaluation_set",
    "EvaluationSetEntity": ".evaluation_set_entity",
    "EvaluationSetEntity_Classifier": ".evaluation_set_entity",
    "EvaluationSetEntity_Extractor": ".evaluation_set_entity",
    "EvaluationSetEntity_Splitter": ".evaluation_set_entity",
    "EvaluationSetItem": ".evaluation_set_item",
    "EvaluationSetItemSummary": ".evaluation_set_item_summary",
    "EvaluationSetRun": ".evaluation_set_run",
    "EvaluationSetRunEntity": ".evaluation_set_run_entity",
    "EvaluationSetRunEntityVersion": ".evaluation_set_run_entity_version",
    "EvaluationSetRunEntityVersion_ClassifierVersion": ".evaluation_set_run_entity_version",
    "EvaluationSetRunEntityVersion_ExtractorVersion": ".evaluation_set_run_entity_version",
    "EvaluationSetRunEntityVersion_SplitterVersion": ".evaluation_set_run_entity_version",
    "EvaluationSetRunEntity_Classifier": ".evaluation_set_run_entity",
    "EvaluationSetRunEntity_Extractor": ".evaluation_set_run_entity",
    "EvaluationSetRunEntity_Splitter": ".evaluation_set_run_entity",
    "EvaluationSetRunMetrics": ".evaluation_set_run_metrics",
    "EvaluationSetRunOptions": ".evaluation_set_run_options",
    "ExcelSheetRange": ".excel_sheet_range",
    "ExternalDataValidationResult": ".external_data_validation_result",
    "ExternalDataValidationResultResponse": ".external_data_validation_result_response",
    "ExternalDataValidationStepRun": ".external_data_validation_step_run",
    "ExternalDataValidationStepRunStep": ".external_data_validation_step_run_step",
    "ExtractAdvancedOptions": ".extract_advanced_options",
    "ExtractAdvancedOptionsArrayCitationStrategy": ".extract_advanced_options_array_citation_strategy",
    "ExtractAdvancedOptionsExcelSheetSelectionStrategy": ".extract_advanced_options_excel_sheet_selection_strategy",
    "ExtractAdvancedOptionsReviewAgent": ".extract_advanced_options_review_agent",
    "ExtractBaseProcessor": ".extract_base_processor",
    "ExtractChunkingOptions": ".extract_chunking_options",
    "ExtractChunkingOptionsChunkSelectionStrategy": ".extract_chunking_options_chunk_selection_strategy",
    "ExtractChunkingOptionsChunkingStrategy": ".extract_chunking_options_chunking_strategy",
    "ExtractConfig": ".extract_config",
    "ExtractConfigJson": ".extract_config_json",
    "ExtractConfigLegacy": ".extract_config_legacy",
    "ExtractConfigLegacyBaseProcessor": ".extract_config_legacy_base_processor",
    "ExtractOutput": ".extract_output",
    "ExtractOutputEdits": ".extract_output_edits",
    "ExtractOutputJson": ".extract_output_json",
    "ExtractOutputLegacy": ".extract_output_legacy",
    "ExtractOutputMetadata": ".extract_output_metadata",
    "ExtractOutputMetadataValue": ".extract_output_metadata_value",
    "ExtractOverrideConfigJson": ".extract_override_config_json",
    "ExtractRequestExtractor": ".extract_request_extractor",
    "ExtractRequestFile": ".extract_request_file",
    "ExtractResult": ".extract_result",
    "ExtractRun": ".extract_run",
    "ExtractRunFailedWebhookEvent": ".extract_run_failed_webhook_event",
    "ExtractRunProcessedWebhookEvent": ".extract_run_processed_webhook_event",
    "ExtractRunSummary": ".extract_run_summary",
    "ExtractStepRun": ".extract_step_run",
    "ExtractStepRunStep": ".extract_step_run_step",
    "ExtractionField": ".extraction_field",
    "ExtractionFieldResult": ".extraction_field_result",
    "ExtractionFieldResultReference": ".extraction_field_result_reference",
    "ExtractionFieldResultReferenceBoundingBoxesItem": ".extraction_field_result_reference_bounding_boxes_item",
    "ExtractionFieldResultType": ".extraction_field_result_type",
    "ExtractionFieldType": ".extraction_field_type",
    "Extractor": ".extractor",
    "ExtractorCreatedWebhookEvent": ".extractor_created_webhook_event",
    "ExtractorDeletedWebhookEvent": ".extractor_deleted_webhook_event",
    "ExtractorDraftUpdatedWebhookEvent": ".extractor_draft_updated_webhook_event",
    "ExtractorSummary": ".extractor_summary",
    "ExtractorUpdatedWebhookEvent": ".extractor_updated_webhook_event",
    "ExtractorVersion": ".extractor_version",
    "ExtractorVersionPublishedWebhookEvent": ".extractor_version_published_webhook_event",
    "ExtractorVersionSummary": ".extractor_version_summary",
    "FigureDetails": ".figure_details",
    "FigureDetailsFigureType": ".figure_details_figure_type",
    "File": ".file",
    "FileContents": ".file_contents",
    "FileContentsPagesItem": ".file_contents_pages_item",
    "FileContentsSectionsItem": ".file_contents_sections_item",
    "FileContentsSheetsItem": ".file_contents_sheets_item",
    "FileFromId": ".file_from_id",
    "FileFromText": ".file_from_text",
    "FileFromUrl": ".file_from_url",
    "FileMetadata": ".file_metadata",
    "FileSummary": ".file_summary",
    "FileType": ".file_type",
    "Insight": ".insight",
    "JsonObject": ".json_object",
    "LegacyBatchProcessorRun": ".legacy_batch_processor_run",
    "LegacyBatchProcessorRunMetrics": ".legacy_batch_processor_run_metrics",
    "LegacyBatchProcessorRunOptions": ".legacy_batch_processor_run_options",
    "LegacyBatchProcessorRunSource": ".legacy_batch_processor_run_source",
    "LegacyBatchProcessorRunStatus": ".legacy_batch_processor_run_status",
    "LegacyClassification": ".legacy_classification",
    "LegacyClassificationAdvancedOptions": ".legacy_classification_advanced_options",
    "LegacyClassificationAdvancedOptionsContext": ".legacy_classification_advanced_options_context",
    "LegacyClassificationConfig": ".legacy_classification_config",
    "LegacyClassificationConfigBaseProcessor": ".legacy_classification_config_base_processor",
    "LegacyClassifierOutput": ".legacy_classifier_output",
    "LegacyDocumentProcessorRunCredits": ".legacy_document_processor_run_credits",
    "LegacyError": ".legacy_error",
    "LegacyExtendError": ".legacy_extend_error",
    "LegacyExtractChunkingOptions": ".legacy_extract_chunking_options",
    "LegacyExtractChunkingOptionsChunkSelectionStrategy": ".legacy_extract_chunking_options_chunk_selection_strategy",
    "LegacyExtractChunkingOptionsChunkingStrategy": ".legacy_extract_chunking_options_chunking_strategy",
    "LegacyExtractionAdvancedOptions": ".legacy_extraction_advanced_options",
    "LegacyExtractionAdvancedOptionsArrayCitationStrategy": ".legacy_extraction_advanced_options_array_citation_strategy",
    "LegacyExtractionAdvancedOptionsExcelSheetSelectionStrategy": ".legacy_extraction_advanced_options_excel_sheet_selection_strategy",
    "LegacyExtractionAdvancedOptionsReviewAgent": ".legacy_extraction_advanced_options_review_agent",
    "LegacyExtractionConfig": ".legacy_extraction_config",
    "LegacyExtractionConfigBaseProcessor": ".legacy_extraction_config_base_processor",
    "LegacyExtractionField": ".legacy_extraction_field",
    "LegacyExtractionFieldResult": ".legacy_extraction_field_result",
    "LegacyExtractionFieldResultType": ".legacy_extraction_field_result_type",
    "LegacyExtractionFieldType": ".legacy_extraction_field_type",
    "LegacyExtractionOutput": ".legacy_extraction_output",
    "LegacyExtractionOutputEdits": ".legacy_extraction_output_edits",
    "LegacyFieldsArrayOutput": ".legacy_fields_array_output",
    "LegacyJsonObject": ".legacy_json_object",
    "LegacyJsonOutput": ".legacy_json_output",
    "LegacyJsonOutputMetadataValue": ".legacy_json_output_metadata_value",
    "LegacyJsonOutputMetadataValueCitationsItem": ".legacy_json_output_metadata_value_citations_item",
    "LegacyJsonOutputMetadataValueCitationsItemPolygonItem": ".legacy_json_output_metadata_value_citations_item_polygon_item",
    "LegacyListProcessorsProcessor": ".legacy_list_processors_processor",
    "LegacyListProcessorsProcessorVersion": ".legacy_list_processors_processor_version",
    "LegacyListProcessorsResponse": ".legacy_list_processors_response",
    "LegacyMaxPageSize": ".legacy_max_page_size",
    "LegacyNextPageToken": ".legacy_next_page_token",
    "LegacyProcessor": ".legacy_processor",
    "LegacyProcessorId": ".legacy_processor_id",
    "LegacyProcessorOutput": ".legacy_processor_output",
    "LegacyProcessorRun": ".legacy_processor_run",
    "LegacyProcessorRunConfig": ".legacy_processor_run_config",
    "LegacyProcessorRunConfig_Classify": ".legacy_processor_run_config",
    "LegacyProcessorRunConfig_Extract": ".legacy_processor_run_config",
    "LegacyProcessorRunConfig_Splitter": ".legacy_processor_run_config",
    "LegacyProcessorRunFileInput": ".legacy_processor_run_file_input",
    "LegacyProcessorRunMergedProcessorsItem": ".legacy_processor_run_merged_processors_item",
    "LegacyProcessorRunSummary": ".legacy_processor_run_summary",
    "LegacyProcessorRunSummaryType": ".legacy_processor_run_summary_type",
    "LegacyProcessorRunType": ".legacy_processor_run_type",
    "LegacyProcessorStatus": ".legacy_processor_status",
    "LegacyProcessorType": ".legacy_processor_type",
    "LegacyProcessorVersion": ".legacy_processor_version",
    "LegacyProcessorVersionConfig": ".legacy_processor_version_config",
    "LegacyProcessorVersionConfig_Classify": ".legacy_processor_version_config",
    "LegacyProcessorVersionConfig_Extract": ".legacy_processor_version_config",
    "LegacyProcessorVersionConfig_Splitter": ".legacy_processor_version_config",
    "LegacyProvidedClassifierOutput": ".legacy_provided_classifier_output",
    "LegacyProvidedExtractionFieldResult": ".legacy_provided_extraction_field_result",
    "LegacyProvidedExtractionFieldResultType": ".legacy_provided_extraction_field_result_type",
    "LegacyProvidedExtractionOutput": ".legacy_provided_extraction_output",
    "LegacyProvidedFieldsArrayOutput": ".legacy_provided_fields_array_output",
    "LegacyProvidedJsonOutput": ".legacy_provided_json_output",
    "LegacyProvidedProcessorOutput": ".legacy_provided_processor_output",
    "LegacyProvidedSplitterOutput": ".legacy_provided_splitter_output",
    "LegacyProvidedSplitterOutputSplitsItem": ".legacy_provided_splitter_output_splits_item",
    "LegacySortByEnum": ".legacy_sort_by_enum",
    "LegacySortDirEnum": ".legacy_sort_dir_enum",
    "LegacySplitterAdvancedOptions": ".legacy_splitter_advanced_options",
    "LegacySplitterAdvancedOptionsSplitMethod": ".legacy_splitter_advanced_options_split_method",
    "LegacySplitterConfig": ".legacy_splitter_config",
    "LegacySplitterConfigBaseProcessor": ".legacy_splitter_config_base_processor",
    "LegacySplitterOutput": ".legacy_splitter_output",
    "LegacySplitterOutputSplitsItem": ".legacy_splitter_output_splits_item",
    "MaxPageSize": ".max_page_size",
    "MergeExtractResult": ".merge_extract_result",
    "MergeExtractResultMergedExtractorsItem": ".merge_extract_result_merged_extractors_item",
    "MergeExtractStepRun": ".merge_extract_step_run",
    "MergeExtractStepRunStep": ".merge_extract_step_run_step",
    "NextPageToken": ".next_page_token",
    "PageRanges": ".page_ranges",
    "PageRangesItem": ".page_ranges_item",
    "ParentSplit": ".parent_split",
    "ParseConfig": ".parse_config",
    "ParseConfigAdvancedOptions": ".parse_config_advanced_options",
    "ParseConfigAdvancedOptionsExcelParsingMode": ".parse_config_advanced_options_excel_parsing_mode",
    "ParseConfigAdvancedOptionsReturnOcr": ".parse_config_advanced_options_return_ocr",
    "ParseConfigBlockOptions": ".parse_config_block_options",
    "ParseConfigBlockOptionsFigures": ".parse_config_block_options_figures",
    "ParseConfigBlockOptionsTables": ".parse_config_block_options_tables",
    "ParseConfigBlockOptionsTablesAgentic": ".parse_config_block_options_tables_agentic",
    "ParseConfigBlockOptionsTablesTargetFormat": ".parse_config_block_options_tables_target_format",
    "ParseConfigBlockOptionsText": ".parse_config_block_options_text",
    "ParseConfigBlockOptionsTextAgentic": ".parse_config_block_options_text_agentic",
    "ParseConfigChunkingStrategy": ".parse_config_chunking_strategy",
    "ParseConfigChunkingStrategyOptions": ".parse_config_chunking_strategy_options",
    "ParseConfigChunkingStrategyType": ".parse_config_chunking_strategy_type",
    "ParseConfigEngine": ".parse_config_engine",
    "ParseConfigTarget": ".parse_config_target",
    "ParseRequestFile": ".parse_request_file",
    "ParseRequestResponseType": ".parse_request_response_type",
    "ParseResult": ".parse_result",
    "ParseRun": ".parse_run",
    "ParseRunFailedWebhookEvent": ".parse_run_failed_webhook_event",
    "ParseRunMetrics": ".parse_run_metrics",
    "ParseRunOutput": ".parse_run_output",
    "ParseRunOutputOcr": ".parse_run_output_ocr",
    "ParseRunOutputOcrWordsItem": ".parse_run_output_ocr_words_item",
    "ParseRunProcessedWebhookEvent": ".parse_run_processed_webhook_event",
    "ParseRunStatus": ".parse_run_status",
    "ParseRunStatusEnum": ".parse_run_status_enum",
    "ParseRunStatusStatus": ".parse_run_status_status",
    "ParseStepRun": ".parse_step_run",
    "ParseStepRunStep": ".parse_step_run_step",
    "Polygon": ".polygon",
    "ProcessorRunStatus": ".processor_run_status",
    "ProcessorVersionString": ".processor_version_string",
    "ProvidedClassifyOutput": ".provided_classify_output",
    "ProvidedExtractOutput": ".provided_extract_output",
    "ProvidedProcessorOutput": ".provided_processor_output",
    "ProvidedSplitOutput": ".provided_split_output",
    "ProvidedSplitOutputSplitsItem": ".provided_split_output_splits_item",
    "ReleaseType": ".release_type",
    "RuleValidationResult": ".rule_validation_result",
    "RuleValidationResultRulesItem": ".rule_validation_result_rules_item",
    "RuleValidationResultRulesItemFailureReason": ".rule_validation_result_rules_item_failure_reason",
    "RuleValidationStepRun": ".rule_validation_step_run",
    "RuleValidationStepRunStep": ".rule_validation_step_run_step",
    "RunMetadata": ".run_metadata",
    "RunPriority": ".run_priority",
    "RunSecrets": ".run_secrets",
    "RunSource": ".run_source",
    "RunSourceId": ".run_source_id",
    "RunUsage": ".run_usage",
    "SortBy": ".sort_by",
    "SortDir": ".sort_dir",
    "SplitAdvancedOptions": ".split_advanced_options",
    "SplitAdvancedOptionsSplitMethod": ".split_advanced_options_split_method",
    "SplitBaseProcessor": ".split_base_processor",
    "SplitConfig": ".split_config",
    "SplitOutput": ".split_output",
    "SplitOutputSplitsItem": ".split_output_splits_item",
    "SplitOverrideConfig": ".split_override_config",
    "SplitRequestFile": ".split_request_file",
    "SplitRequestSplitter": ".split_request_splitter",
    "SplitResult": ".split_result",
    "SplitRun": ".split_run",
    "SplitRunFailedWebhookEvent": ".split_run_failed_webhook_event",
    "SplitRunProcessedWebhookEvent": ".split_run_processed_webhook_event",
    "SplitRunSummary": ".split_run_summary",
    "SplitStepRun": ".split_step_run",
    "SplitStepRunStep": ".split_step_run_step",
    "Splitter": ".splitter",
    "SplitterCreatedWebhookEvent": ".splitter_created_webhook_event",
    "SplitterDeletedWebhookEvent": ".splitter_deleted_webhook_event",
    "SplitterDraftUpdatedWebhookEvent": ".splitter_draft_updated_webhook_event",
    "SplitterSummary": ".splitter_summary",
    "SplitterUpdatedWebhookEvent": ".splitter_updated_webhook_event",
    "SplitterVersion": ".splitter_version",
    "SplitterVersionPublishedWebhookEvent": ".splitter_version_published_webhook_event",
    "SplitterVersionSummary": ".splitter_version_summary",
    "StepRun": ".step_run",
    "StepRunBase": ".step_run_base",
    "StepRunBaseStatus": ".step_run_base_status",
    "TableCellDetails": ".table_cell_details",
    "TableDetails": ".table_details",
    "TooManyRequestsErrorBody": ".too_many_requests_error_body",
    "UpdatedAt": ".updated_at",
    "VersionDescription": ".version_description",
    "WebhookAdvancedOptions": ".webhook_advanced_options",
    "WebhookEndpoint": ".webhook_endpoint",
    "WebhookEndpointCreate": ".webhook_endpoint_create",
    "WebhookEndpointEventType": ".webhook_endpoint_event_type",
    "WebhookEndpointStatus": ".webhook_endpoint_status",
    "WebhookEvent": ".webhook_event",
    "WebhookEvent_ClassifierCreated": ".webhook_event",
    "WebhookEvent_ClassifierDeleted": ".webhook_event",
    "WebhookEvent_ClassifierDraftUpdated": ".webhook_event",
    "WebhookEvent_ClassifierUpdated": ".webhook_event",
    "WebhookEvent_ClassifierVersionPublished": ".webhook_event",
    "WebhookEvent_ClassifyRunFailed": ".webhook_event",
    "WebhookEvent_ClassifyRunProcessed": ".webhook_event",
    "WebhookEvent_EditRunFailed": ".webhook_event",
    "WebhookEvent_EditRunProcessed": ".webhook_event",
    "WebhookEvent_ExtractRunFailed": ".webhook_event",
    "WebhookEvent_ExtractRunProcessed": ".webhook_event",
    "WebhookEvent_ExtractorCreated": ".webhook_event",
    "WebhookEvent_ExtractorDeleted": ".webhook_event",
    "WebhookEvent_ExtractorDraftUpdated": ".webhook_event",
    "WebhookEvent_ExtractorUpdated": ".webhook_event",
    "WebhookEvent_ExtractorVersionPublished": ".webhook_event",
    "WebhookEvent_ParseRunFailed": ".webhook_event",
    "WebhookEvent_ParseRunProcessed": ".webhook_event",
    "WebhookEvent_SplitRunFailed": ".webhook_event",
    "WebhookEvent_SplitRunProcessed": ".webhook_event",
    "WebhookEvent_SplitterCreated": ".webhook_event",
    "WebhookEvent_SplitterDeleted": ".webhook_event",
    "WebhookEvent_SplitterDraftUpdated": ".webhook_event",
    "WebhookEvent_SplitterUpdated": ".webhook_event",
    "WebhookEvent_SplitterVersionPublished": ".webhook_event",
    "WebhookEvent_WorkflowCreated": ".webhook_event",
    "WebhookEvent_WorkflowDeleted": ".webhook_event",
    "WebhookEvent_WorkflowDeployed": ".webhook_event",
    "WebhookEvent_WorkflowRunCancelled": ".webhook_event",
    "WebhookEvent_WorkflowRunCompleted": ".webhook_event",
    "WebhookEvent_WorkflowRunFailed": ".webhook_event",
    "WebhookEvent_WorkflowRunNeedsReview": ".webhook_event",
    "WebhookEvent_WorkflowRunRejected": ".webhook_event",
    "WebhookEvent_WorkflowRunStepRunProcessed": ".webhook_event",
    "WebhookPayloadFormat": ".webhook_payload_format",
    "WebhookPayloadOptions": ".webhook_payload_options",
    "WebhookSubscription": ".webhook_subscription",
    "WebhookSubscriptionEventType": ".webhook_subscription_event_type",
    "WebhookSubscriptionResourceType": ".webhook_subscription_resource_type",
    "Workflow": ".workflow",
    "WorkflowCreatedWebhookEvent": ".workflow_created_webhook_event",
    "WorkflowDeletedWebhookEvent": ".workflow_deleted_webhook_event",
    "WorkflowDeployedWebhookEvent": ".workflow_deployed_webhook_event",
    "WorkflowReference": ".workflow_reference",
    "WorkflowRun": ".workflow_run",
    "WorkflowRunCancelledWebhookEvent": ".workflow_run_cancelled_webhook_event",
    "WorkflowRunCompletedWebhookEvent": ".workflow_run_completed_webhook_event",
    "WorkflowRunFailedWebhookEvent": ".workflow_run_failed_webhook_event",
    "WorkflowRunNeedsReviewWebhookEvent": ".workflow_run_needs_review_webhook_event",
    "WorkflowRunRejectedWebhookEvent": ".workflow_run_rejected_webhook_event",
    "WorkflowRunStatus": ".workflow_run_status",
    "WorkflowRunStepRunProcessedWebhookEvent": ".workflow_run_step_run_processed_webhook_event",
    "WorkflowRunSummary": ".workflow_run_summary",
    "WorkflowStepBase": ".workflow_step_base",
    "WorkflowSummary": ".workflow_summary",
    "WorkflowVersion": ".workflow_version",
    "WorkflowVersionSummary": ".workflow_version_summary",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "ApiError",
    "ApiVersionEnum",
    "ArrayStrategy",
    "ArrayStrategyType",
    "BatchProcessorRun",
    "BatchProcessorRunMetrics",
    "BatchProcessorRunOptions",
    "BatchProcessorRunSource",
    "BatchProcessorRunStatus",
    "BatchRun",
    "BatchRunEntity",
    "BatchRunEntityVersion",
    "BatchRunEntityVersion_ClassifierVersion",
    "BatchRunEntityVersion_ExtractorVersion",
    "BatchRunEntityVersion_SplitterVersion",
    "BatchRunEntity_Classifier",
    "BatchRunEntity_Extractor",
    "BatchRunEntity_Splitter",
    "BatchRunMetrics",
    "BatchRunStatus",
    "Block",
    "BlockDetails",
    "BlockMetadata",
    "BlockMetadataPage",
    "BlockPolygonItem",
    "BlockType",
    "BoundingBox",
    "Chunk",
    "ChunkMetadata",
    "ChunkMetadataPageRange",
    "ChunkType",
    "Citation",
    "CitationPage",
    "Classification",
    "Classifications",
    "Classifier",
    "ClassifierCreatedWebhookEvent",
    "ClassifierDeletedWebhookEvent",
    "ClassifierDraftUpdatedWebhookEvent",
    "ClassifierSummary",
    "ClassifierUpdatedWebhookEvent",
    "ClassifierVersion",
    "ClassifierVersionPublishedWebhookEvent",
    "ClassifierVersionSummary",
    "ClassifyAdvancedOptions",
    "ClassifyAdvancedOptionsContext",
    "ClassifyBaseProcessor",
    "ClassifyConfig",
    "ClassifyOutput",
    "ClassifyOverrideConfig",
    "ClassifyRequestClassifier",
    "ClassifyRequestFile",
    "ClassifyResult",
    "ClassifyRun",
    "ClassifyRunFailedWebhookEvent",
    "ClassifyRunProcessedWebhookEvent",
    "ClassifyRunSummary",
    "ClassifyStepRun",
    "ClassifyStepRunStep",
    "ConditionalExtractResult",
    "ConditionalExtractStepRun",
    "ConditionalExtractStepRunStep",
    "CreatedAt",
    "EditBoundingBox",
    "EditConfig",
    "EditConfigAdvancedOptions",
    "EditJson",
    "EditJsonExtendEditFieldType",
    "EditObjectJson",
    "EditRequestFile",
    "EditRootJson",
    "EditRun",
    "EditRunFailedWebhookEvent",
    "EditRunMetrics",
    "EditRunOutput",
    "EditRunOutputEditedFile",
    "EditRunProcessedWebhookEvent",
    "EditRunStatus",
    "EditTextOptions",
    "EmptyBlockDetails",
    "Enum",
    "EnumOption",
    "EvaluationSet",
    "EvaluationSetEntity",
    "EvaluationSetEntity_Classifier",
    "EvaluationSetEntity_Extractor",
    "EvaluationSetEntity_Splitter",
    "EvaluationSetItem",
    "EvaluationSetItemSummary",
    "EvaluationSetRun",
    "EvaluationSetRunEntity",
    "EvaluationSetRunEntityVersion",
    "EvaluationSetRunEntityVersion_ClassifierVersion",
    "EvaluationSetRunEntityVersion_ExtractorVersion",
    "EvaluationSetRunEntityVersion_SplitterVersion",
    "EvaluationSetRunEntity_Classifier",
    "EvaluationSetRunEntity_Extractor",
    "EvaluationSetRunEntity_Splitter",
    "EvaluationSetRunMetrics",
    "EvaluationSetRunOptions",
    "ExcelSheetRange",
    "ExternalDataValidationResult",
    "ExternalDataValidationResultResponse",
    "ExternalDataValidationStepRun",
    "ExternalDataValidationStepRunStep",
    "ExtractAdvancedOptions",
    "ExtractAdvancedOptionsArrayCitationStrategy",
    "ExtractAdvancedOptionsExcelSheetSelectionStrategy",
    "ExtractAdvancedOptionsReviewAgent",
    "ExtractBaseProcessor",
    "ExtractChunkingOptions",
    "ExtractChunkingOptionsChunkSelectionStrategy",
    "ExtractChunkingOptionsChunkingStrategy",
    "ExtractConfig",
    "ExtractConfigJson",
    "ExtractConfigLegacy",
    "ExtractConfigLegacyBaseProcessor",
    "ExtractOutput",
    "ExtractOutputEdits",
    "ExtractOutputJson",
    "ExtractOutputLegacy",
    "ExtractOutputMetadata",
    "ExtractOutputMetadataValue",
    "ExtractOverrideConfigJson",
    "ExtractRequestExtractor",
    "ExtractRequestFile",
    "ExtractResult",
    "ExtractRun",
    "ExtractRunFailedWebhookEvent",
    "ExtractRunProcessedWebhookEvent",
    "ExtractRunSummary",
    "ExtractStepRun",
    "ExtractStepRunStep",
    "ExtractionField",
    "ExtractionFieldResult",
    "ExtractionFieldResultReference",
    "ExtractionFieldResultReferenceBoundingBoxesItem",
    "ExtractionFieldResultType",
    "ExtractionFieldType",
    "Extractor",
    "ExtractorCreatedWebhookEvent",
    "ExtractorDeletedWebhookEvent",
    "ExtractorDraftUpdatedWebhookEvent",
    "ExtractorSummary",
    "ExtractorUpdatedWebhookEvent",
    "ExtractorVersion",
    "ExtractorVersionPublishedWebhookEvent",
    "ExtractorVersionSummary",
    "FigureDetails",
    "FigureDetailsFigureType",
    "File",
    "FileContents",
    "FileContentsPagesItem",
    "FileContentsSectionsItem",
    "FileContentsSheetsItem",
    "FileFromId",
    "FileFromText",
    "FileFromUrl",
    "FileMetadata",
    "FileSummary",
    "FileType",
    "Insight",
    "JsonObject",
    "LegacyBatchProcessorRun",
    "LegacyBatchProcessorRunMetrics",
    "LegacyBatchProcessorRunOptions",
    "LegacyBatchProcessorRunSource",
    "LegacyBatchProcessorRunStatus",
    "LegacyClassification",
    "LegacyClassificationAdvancedOptions",
    "LegacyClassificationAdvancedOptionsContext",
    "LegacyClassificationConfig",
    "LegacyClassificationConfigBaseProcessor",
    "LegacyClassifierOutput",
    "LegacyDocumentProcessorRunCredits",
    "LegacyError",
    "LegacyExtendError",
    "LegacyExtractChunkingOptions",
    "LegacyExtractChunkingOptionsChunkSelectionStrategy",
    "LegacyExtractChunkingOptionsChunkingStrategy",
    "LegacyExtractionAdvancedOptions",
    "LegacyExtractionAdvancedOptionsArrayCitationStrategy",
    "LegacyExtractionAdvancedOptionsExcelSheetSelectionStrategy",
    "LegacyExtractionAdvancedOptionsReviewAgent",
    "LegacyExtractionConfig",
    "LegacyExtractionConfigBaseProcessor",
    "LegacyExtractionField",
    "LegacyExtractionFieldResult",
    "LegacyExtractionFieldResultType",
    "LegacyExtractionFieldType",
    "LegacyExtractionOutput",
    "LegacyExtractionOutputEdits",
    "LegacyFieldsArrayOutput",
    "LegacyJsonObject",
    "LegacyJsonOutput",
    "LegacyJsonOutputMetadataValue",
    "LegacyJsonOutputMetadataValueCitationsItem",
    "LegacyJsonOutputMetadataValueCitationsItemPolygonItem",
    "LegacyListProcessorsProcessor",
    "LegacyListProcessorsProcessorVersion",
    "LegacyListProcessorsResponse",
    "LegacyMaxPageSize",
    "LegacyNextPageToken",
    "LegacyProcessor",
    "LegacyProcessorId",
    "LegacyProcessorOutput",
    "LegacyProcessorRun",
    "LegacyProcessorRunConfig",
    "LegacyProcessorRunConfig_Classify",
    "LegacyProcessorRunConfig_Extract",
    "LegacyProcessorRunConfig_Splitter",
    "LegacyProcessorRunFileInput",
    "LegacyProcessorRunMergedProcessorsItem",
    "LegacyProcessorRunSummary",
    "LegacyProcessorRunSummaryType",
    "LegacyProcessorRunType",
    "LegacyProcessorStatus",
    "LegacyProcessorType",
    "LegacyProcessorVersion",
    "LegacyProcessorVersionConfig",
    "LegacyProcessorVersionConfig_Classify",
    "LegacyProcessorVersionConfig_Extract",
    "LegacyProcessorVersionConfig_Splitter",
    "LegacyProvidedClassifierOutput",
    "LegacyProvidedExtractionFieldResult",
    "LegacyProvidedExtractionFieldResultType",
    "LegacyProvidedExtractionOutput",
    "LegacyProvidedFieldsArrayOutput",
    "LegacyProvidedJsonOutput",
    "LegacyProvidedProcessorOutput",
    "LegacyProvidedSplitterOutput",
    "LegacyProvidedSplitterOutputSplitsItem",
    "LegacySortByEnum",
    "LegacySortDirEnum",
    "LegacySplitterAdvancedOptions",
    "LegacySplitterAdvancedOptionsSplitMethod",
    "LegacySplitterConfig",
    "LegacySplitterConfigBaseProcessor",
    "LegacySplitterOutput",
    "LegacySplitterOutputSplitsItem",
    "MaxPageSize",
    "MergeExtractResult",
    "MergeExtractResultMergedExtractorsItem",
    "MergeExtractStepRun",
    "MergeExtractStepRunStep",
    "NextPageToken",
    "PageRanges",
    "PageRangesItem",
    "ParentSplit",
    "ParseConfig",
    "ParseConfigAdvancedOptions",
    "ParseConfigAdvancedOptionsExcelParsingMode",
    "ParseConfigAdvancedOptionsReturnOcr",
    "ParseConfigBlockOptions",
    "ParseConfigBlockOptionsFigures",
    "ParseConfigBlockOptionsTables",
    "ParseConfigBlockOptionsTablesAgentic",
    "ParseConfigBlockOptionsTablesTargetFormat",
    "ParseConfigBlockOptionsText",
    "ParseConfigBlockOptionsTextAgentic",
    "ParseConfigChunkingStrategy",
    "ParseConfigChunkingStrategyOptions",
    "ParseConfigChunkingStrategyType",
    "ParseConfigEngine",
    "ParseConfigTarget",
    "ParseRequestFile",
    "ParseRequestResponseType",
    "ParseResult",
    "ParseRun",
    "ParseRunFailedWebhookEvent",
    "ParseRunMetrics",
    "ParseRunOutput",
    "ParseRunOutputOcr",
    "ParseRunOutputOcrWordsItem",
    "ParseRunProcessedWebhookEvent",
    "ParseRunStatus",
    "ParseRunStatusEnum",
    "ParseRunStatusStatus",
    "ParseStepRun",
    "ParseStepRunStep",
    "Polygon",
    "ProcessorRunStatus",
    "ProcessorVersionString",
    "ProvidedClassifyOutput",
    "ProvidedExtractOutput",
    "ProvidedProcessorOutput",
    "ProvidedSplitOutput",
    "ProvidedSplitOutputSplitsItem",
    "ReleaseType",
    "RuleValidationResult",
    "RuleValidationResultRulesItem",
    "RuleValidationResultRulesItemFailureReason",
    "RuleValidationStepRun",
    "RuleValidationStepRunStep",
    "RunMetadata",
    "RunPriority",
    "RunSecrets",
    "RunSource",
    "RunSourceId",
    "RunUsage",
    "SortBy",
    "SortDir",
    "SplitAdvancedOptions",
    "SplitAdvancedOptionsSplitMethod",
    "SplitBaseProcessor",
    "SplitConfig",
    "SplitOutput",
    "SplitOutputSplitsItem",
    "SplitOverrideConfig",
    "SplitRequestFile",
    "SplitRequestSplitter",
    "SplitResult",
    "SplitRun",
    "SplitRunFailedWebhookEvent",
    "SplitRunProcessedWebhookEvent",
    "SplitRunSummary",
    "SplitStepRun",
    "SplitStepRunStep",
    "Splitter",
    "SplitterCreatedWebhookEvent",
    "SplitterDeletedWebhookEvent",
    "SplitterDraftUpdatedWebhookEvent",
    "SplitterSummary",
    "SplitterUpdatedWebhookEvent",
    "SplitterVersion",
    "SplitterVersionPublishedWebhookEvent",
    "SplitterVersionSummary",
    "StepRun",
    "StepRunBase",
    "StepRunBaseStatus",
    "TableCellDetails",
    "TableDetails",
    "TooManyRequestsErrorBody",
    "UpdatedAt",
    "VersionDescription",
    "WebhookAdvancedOptions",
    "WebhookEndpoint",
    "WebhookEndpointCreate",
    "WebhookEndpointEventType",
    "WebhookEndpointStatus",
    "WebhookEvent",
    "WebhookEvent_ClassifierCreated",
    "WebhookEvent_ClassifierDeleted",
    "WebhookEvent_ClassifierDraftUpdated",
    "WebhookEvent_ClassifierUpdated",
    "WebhookEvent_ClassifierVersionPublished",
    "WebhookEvent_ClassifyRunFailed",
    "WebhookEvent_ClassifyRunProcessed",
    "WebhookEvent_EditRunFailed",
    "WebhookEvent_EditRunProcessed",
    "WebhookEvent_ExtractRunFailed",
    "WebhookEvent_ExtractRunProcessed",
    "WebhookEvent_ExtractorCreated",
    "WebhookEvent_ExtractorDeleted",
    "WebhookEvent_ExtractorDraftUpdated",
    "WebhookEvent_ExtractorUpdated",
    "WebhookEvent_ExtractorVersionPublished",
    "WebhookEvent_ParseRunFailed",
    "WebhookEvent_ParseRunProcessed",
    "WebhookEvent_SplitRunFailed",
    "WebhookEvent_SplitRunProcessed",
    "WebhookEvent_SplitterCreated",
    "WebhookEvent_SplitterDeleted",
    "WebhookEvent_SplitterDraftUpdated",
    "WebhookEvent_SplitterUpdated",
    "WebhookEvent_SplitterVersionPublished",
    "WebhookEvent_WorkflowCreated",
    "WebhookEvent_WorkflowDeleted",
    "WebhookEvent_WorkflowDeployed",
    "WebhookEvent_WorkflowRunCancelled",
    "WebhookEvent_WorkflowRunCompleted",
    "WebhookEvent_WorkflowRunFailed",
    "WebhookEvent_WorkflowRunNeedsReview",
    "WebhookEvent_WorkflowRunRejected",
    "WebhookEvent_WorkflowRunStepRunProcessed",
    "WebhookPayloadFormat",
    "WebhookPayloadOptions",
    "WebhookSubscription",
    "WebhookSubscriptionEventType",
    "WebhookSubscriptionResourceType",
    "Workflow",
    "WorkflowCreatedWebhookEvent",
    "WorkflowDeletedWebhookEvent",
    "WorkflowDeployedWebhookEvent",
    "WorkflowReference",
    "WorkflowRun",
    "WorkflowRunCancelledWebhookEvent",
    "WorkflowRunCompletedWebhookEvent",
    "WorkflowRunFailedWebhookEvent",
    "WorkflowRunNeedsReviewWebhookEvent",
    "WorkflowRunRejectedWebhookEvent",
    "WorkflowRunStatus",
    "WorkflowRunStepRunProcessedWebhookEvent",
    "WorkflowRunSummary",
    "WorkflowStepBase",
    "WorkflowSummary",
    "WorkflowVersion",
    "WorkflowVersionSummary",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class LegacyExtractionAdvancedOptionsReviewAgent(UncheckedBaseModel):
    """
    Configuration for the review agent that analyzes extraction results.
    When enabled, each field in the output metadata will include a `reviewAgentScore` (1-5)
    and may include additional `insights` of type `issue` or `review_summary` to help identify
    fields that may need manual review.

    To learn more, view the [Review Agent Documentation](https://docs.extend.ai/2026-02-09/product/extraction/review-agent)
    """

    enabled: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether to enable the review agent for the extraction output.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.legacy_classification_advanced_options_context import LegacyClassificationAdvancedOptionsContext
from .page_ranges import PageRangesParams


class LegacyClassificationAdvancedOptionsParams(typing_extensions.TypedDict):
    context: typing_extensions.NotRequired[LegacyClassificationAdvancedOptionsContext]
    """
    The context to use for classification.
    """

    advanced_multimodal_enabled: typing_extensions.NotRequired[
        typing_extensions.Annotated[bool, FieldMetadata(alias="advancedMultimodalEnabled")]
    ]
    """
    Enable advanced multimodal processing for better handling of visual elements during classification.
    """

    fixed_page_limit: typing_extensions.NotRequired[
        typing_extensions.Annotated[int, FieldMetadata(alias="fixedPageLimit")]
    ]
    """
    Limit processing to a specific number of pages from the beginning of the document. See [Page Ranges](https://docs.extend.ai/2026-02-09/product/page-ranges).
    """

    page_ranges: typing_extensions.NotRequired[
        typing_extensions.Annotated[PageRangesParams, FieldMetadata(alias="pageRanges")]
    ]



# This file was auto-generated by Fern from our API Definition.

import typing

from .extract_config_json import ExtractConfigJson
from .extract_config_legacy import ExtractConfigLegacy

ExtractConfig = typing.Union[ExtractConfigJson, ExtractConfigLegacy]



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class LegacyErrorParams(typing_extensions.TypedDict):
    success: typing_extensions.NotRequired[bool]
    error: typing_extensions.NotRequired[str]
    """
    Error message
    """



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.json_object import JsonObject


class ExternalDataValidationResultResponseParams(typing_extensions.TypedDict):
    """
    The response from the external validation endpoint.
    """

    status: int
    """
    The HTTP status code returned by the external endpoint.
    """

    data: JsonObject
    """
    The JSON response body returned by the external endpoint.
    """



"""
Custom error classes for the Extend SDK wrapper.
"""


class PollingTimeoutError(Exception):
    """Error thrown when polling exceeds the maximum wait time."""

    def __init__(self, message: str, elapsed_ms: int, max_wait_ms: int):
        super().__init__(message)
        self.elapsed_ms = elapsed_ms
        self.max_wait_ms = max_wait_ms


class WebhookSignatureVerificationError(Exception):
    """Error thrown when webhook signature verification fails."""

    pass


class WebhookPayloadFetchError(Exception):
    """Error thrown when fetching signed URL payload fails."""

    pass


class WebhookParseError(Exception):
    """Error thrown when webhook body cannot be parsed."""

    pass


class SignedUrlNotAllowedError(Exception):
    """Error thrown when a signed URL payload is received but not allowed."""

    def __init__(self):
        super().__init__(
            "Received signed URL payload but allow_signed_url option is not enabled. "
            "Either pass allow_signed_url=True to verify_and_parse() to handle signed URL payloads, "
            "or configure your webhook endpoint in the Extend dashboard to not use signed URLs."
        )



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .chunk import ChunkParams
from .parse_run_output_ocr import ParseRunOutputOcrParams


class ParseRunOutputParams(typing_extensions.TypedDict):
    """
    The parse run output.

    **Availability:** Present when `status` is `"PROCESSED"` and the request was made without the `responseType=url` query parameter. Contains the parsed chunks.
    """

    chunks: typing.Sequence[ChunkParams]
    """
    An array of chunks that were parsed from the file.
    """

    ocr: typing_extensions.NotRequired[ParseRunOutputOcrParams]
    """
    Raw OCR data from the parsing process. Only included when `returnOcr` is configured in the parse config's advanced options.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class ExtractChunkingOptionsChunkSelectionStrategy(enum.StrEnum):
    """
    The strategy to use for selecting chunks.
    """

    INTELLIGENT = "intelligent"
    CONFIDENCE = "confidence"
    TAKE_FIRST = "take_first"
    TAKE_LAST = "take_last"
    _UNKNOWN = "__EXTRACTCHUNKINGOPTIONSCHUNKSELECTIONSTRATEGY_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ExtractChunkingOptionsChunkSelectionStrategy":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        intelligent: typing.Callable[[], T_Result],
        confidence: typing.Callable[[], T_Result],
        take_first: typing.Callable[[], T_Result],
        take_last: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ExtractChunkingOptionsChunkSelectionStrategy.INTELLIGENT:
            return intelligent()
        if self is ExtractChunkingOptionsChunkSelectionStrategy.CONFIDENCE:
            return confidence()
        if self is ExtractChunkingOptionsChunkSelectionStrategy.TAKE_FIRST:
            return take_first()
        if self is ExtractChunkingOptionsChunkSelectionStrategy.TAKE_LAST:
            return take_last()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import datetime as dt

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.legacy_processor_type import LegacyProcessorType
from .legacy_processor_version_config import LegacyProcessorVersionConfigParams


class LegacyProcessorVersionParams(typing_extensions.TypedDict):
    object: str
    """
    The type of the object. In this case, it will always be `"document_processor_version"`.
    """

    id: str
    """
    The unique identifier for this version of the document processor.
    
    Example: `"exv_xK9mLPqRtN3vS8wF5hB2cQ"`
    """

    processor_id: typing_extensions.Annotated[str, FieldMetadata(alias="processorId")]
    """
    The ID of the parent document processor.
    
    Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`
    """

    processor_name: typing_extensions.NotRequired[
        typing_extensions.Annotated[str, FieldMetadata(alias="processorName")]
    ]
    """
    The name of the parent document processor.
    
    Example: `"Invoice Processor"`
    """

    processor_type: typing_extensions.Annotated[LegacyProcessorType, FieldMetadata(alias="processorType")]
    description: typing_extensions.NotRequired[str]
    """
    An optional description of this version of the document processor.
    
    Example: `"Updated extraction fields for new invoice format"`
    """

    version: str
    """
    The version number or identifier for this specific version of the document processor. The draft version will have version="draft".
    
    Examples: `"1.0"`, `"2.1"`, `"draft"`
    """

    config: LegacyProcessorVersionConfigParams
    """
    The configuration settings for this version of the document processor. The structure of this object will vary depending on the processor type.
    
    See the configuration section in the "Guides" tab, for yout specific processor type, for more details on the configuration settings.
    """

    created_at: typing_extensions.Annotated[dt.datetime, FieldMetadata(alias="createdAt")]
    """
    The time (in UTC) at which this version of the document processor was created. Will follow the RFC 3339 format.
    
    Example: `"2024-03-21T15:30:00Z"`
    """

    updated_at: typing_extensions.Annotated[dt.datetime, FieldMetadata(alias="updatedAt")]
    """
    The time (in UTC) at which this version of the document processor was last updated. Will follow the RFC 3339 format.
    
    Example: `"2024-03-21T16:45:00Z"`
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class EvaluationSetRunOptions(UncheckedBaseModel):
    """
    The options for the evaluation set run.
    """

    fuzzy_match_fields: typing_extensions.Annotated[
        typing.Optional[typing.List[str]], FieldMetadata(alias="fuzzyMatchFields")
    ] = pydantic.Field(alias="fuzzyMatchFields", default=None)
    """
    The fields that were fuzzy matched.
    """

    exclude_fields: typing_extensions.Annotated[
        typing.Optional[typing.List[str]], FieldMetadata(alias="excludeFields")
    ] = pydantic.Field(alias="excludeFields", default=None)
    """
    The fields that were excluded from the run.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



"""
Polling utilities with hybrid polling strategy: fast initial polls followed
by exponential backoff with proportional jitter.

The default strategy polls at 1-second intervals for the first 30 seconds,
then gradually increases the interval using exponential backoff (1.15x multiplier)
up to a maximum of 30 seconds between polls.

Example:
    # Polls until complete (uses hybrid strategy by default)
    result = poll_until_done(
        retrieve=lambda: client.extract_runs.retrieve(id),
        is_terminal=lambda res: res.extract_run.status != "PROCESSING"
    )

    # With custom timeout
    result = poll_until_done(
        retrieve=lambda: client.extract_runs.retrieve(id),
        is_terminal=lambda res: res.extract_run.status != "PROCESSING",
        options=PollingOptions(max_wait_ms=300000)  # 5 minute timeout
    )

    # Custom fast polling phase
    result = poll_until_done(
        retrieve=lambda: client.extract_runs.retrieve(id),
        is_terminal=lambda res: res.extract_run.status != "PROCESSING",
        options=PollingOptions(
            fast_poll_duration_ms=60000,  # Fast poll for 60 seconds
            fast_poll_interval_ms=500,    # Poll every 500ms during fast phase
        )
    )
"""

import asyncio
import random
import time
from dataclasses import dataclass
from typing import Awaitable, Callable, Optional, TypeVar

T = TypeVar("T")


@dataclass
class PollingOptions:
    """
    Configuration options for polling behavior.

    Attributes:
        max_wait_ms: Maximum total wait time in milliseconds. Default: None (polls indefinitely).
        fast_poll_duration_ms: Duration of the fast polling phase in milliseconds.
            During this phase, polls occur at a fixed interval (fast_poll_interval_ms).
            Default: 30000 (30 seconds).
        fast_poll_interval_ms: Interval between polls during the fast polling phase
            in milliseconds. Default: 1000 (1 second).
        initial_delay_ms: Initial delay for the backoff phase (after fast polling ends)
            in milliseconds. Default: 1000 (1 second).
        max_delay_ms: Maximum delay between polls in milliseconds. Default: 30000 (30 seconds).
        backoff_multiplier: Multiplier for exponential backoff during the backoff phase.
            A value of 1.15 means each delay is 1.15x the previous delay. Default: 1.15.
        jitter_fraction: Jitter fraction for randomization. A value of 0.25 means delays
            will be randomized by +/-25%. Default: 0.25.
    """

    max_wait_ms: Optional[int] = None  # None = poll indefinitely
    fast_poll_duration_ms: int = 30_000  # 30 seconds
    fast_poll_interval_ms: int = 1_000  # 1 second
    initial_delay_ms: int = 1_000  # 1 second
    max_delay_ms: int = 30_000  # 30 seconds
    backoff_multiplier: float = 1.15
    jitter_fraction: float = 0.25


class PollingTimeoutError(Exception):
    """Error thrown when polling exceeds the maximum wait time."""

    def __init__(self, message: str, elapsed_ms: int, max_wait_ms: int):
        super().__init__(message)
        self.elapsed_ms = elapsed_ms
        self.max_wait_ms = max_wait_ms


def calculate_backoff_delay(
    attempt: int,
    initial_delay_ms: int,
    max_delay_ms: int,
    jitter_fraction: float,
    backoff_multiplier: float = 2.0,
) -> int:
    """
    Calculates the next delay using exponential backoff with proportional jitter.

    Args:
        attempt: The current attempt number (0-indexed)
        initial_delay_ms: The base delay for the first attempt
        max_delay_ms: The maximum delay cap
        jitter_fraction: The fraction of delay to randomize (+/-)
        backoff_multiplier: The multiplier for exponential backoff (default: 2)

    Returns:
        The delay in milliseconds
    """
    # Exponential backoff: initialDelay * multiplier^attempt
    exponential_delay = initial_delay_ms * (backoff_multiplier**attempt)

    # Cap at maxDelay
    capped_delay = min(exponential_delay, max_delay_ms)

    # Apply proportional jitter: delay * (1 + random(-jitterFraction, +jitterFraction))
    jitter = (random.random() * 2 - 1) * jitter_fraction
    final_delay = capped_delay * (1 + jitter)

    return round(final_delay)


@dataclass
class HybridDelayOptions:
    """Configuration options for calculating hybrid delay."""

    fast_poll_duration_ms: int
    fast_poll_interval_ms: int
    initial_delay_ms: int
    max_delay_ms: int
    backoff_multiplier: float
    jitter_fraction: float


def calculate_hybrid_delay(elapsed_ms: float, options: HybridDelayOptions) -> int:
    """
    Calculates the delay for a hybrid polling strategy based on elapsed time.

    During the fast polling phase (elapsed < fast_poll_duration_ms), returns a fixed
    interval with jitter. After the fast phase ends, switches to exponential backoff.

    Args:
        elapsed_ms: Total elapsed time since polling started
        options: Configuration options for the hybrid strategy

    Returns:
        The delay in milliseconds until the next poll
    """
    # Fast polling phase: use fixed interval with jitter
    if elapsed_ms < options.fast_poll_duration_ms:
        jitter = (random.random() * 2 - 1) * options.jitter_fraction
        return round(options.fast_poll_interval_ms * (1 + jitter))

    # Backoff phase: calculate attempt number based on time since fast phase ended
    time_since_backoff_start = elapsed_ms - options.fast_poll_duration_ms

    # Calculate which "attempt" we're on based on elapsed time in backoff phase
    # Sum of geometric series: S = a * (r^n - 1) / (r - 1)
    # Solving for n: n = log((S * (r - 1) / a) + 1) / log(r)
    if options.backoff_multiplier == 1:
        # Linear case: attempt = time_since_backoff_start / initial_delay_ms
        attempt = int(time_since_backoff_start / options.initial_delay_ms)
    else:
        import math

        r = options.backoff_multiplier
        a = options.initial_delay_ms
        s = time_since_backoff_start

        # Estimate attempt from geometric series sum formula
        inner_value = (s * (r - 1)) / a + 1
        if inner_value <= 0:
            attempt = 0
        else:
            attempt = int(math.log(inner_value) / math.log(r))

    return calculate_backoff_delay(
        attempt,
        options.initial_delay_ms,
        options.max_delay_ms,
        options.jitter_fraction,
        options.backoff_multiplier,
    )


def poll_until_done(
    retrieve: Callable[[], T],
    is_terminal: Callable[[T], bool],
    options: Optional[PollingOptions] = None,
) -> T:
    """
    Polls a retrieve function until a terminal condition is met (synchronous version).

    Uses a hybrid polling strategy: fast polling at fixed intervals for an initial
    period, then exponential backoff with proportional jitter. This provides low
    latency for quick operations while still reducing server load for longer ones.

    Default behavior:
    - Fast phase: Poll every 1 second for the first 30 seconds
    - Backoff phase: Exponential backoff with 1.15x multiplier, max 30 second delay

    Args:
        retrieve: Function that fetches the current state
        is_terminal: Predicate that returns True when polling should stop
        options: Polling configuration options

    Returns:
        The final result when is_terminal returns True

    Raises:
        PollingTimeoutError: If max_wait_ms is set and exceeded

    Example:
        # Default hybrid polling
        result = poll_until_done(
            retrieve=lambda: client.extract_runs.retrieve(run_id),
            is_terminal=lambda res: res.extract_run.status != "PROCESSING"
        )

        # Pure exponential backoff (disable fast polling phase)
        result = poll_until_done(
            retrieve=lambda: client.extract_runs.retrieve(run_id),
            is_terminal=lambda res: res.extract_run.status != "PROCESSING",
            options=PollingOptions(fast_poll_duration_ms=0)
        )
    """
    if options is None:
        options = PollingOptions()

    max_wait_ms = options.max_wait_ms
    hybrid_options = HybridDelayOptions(
        fast_poll_duration_ms=options.fast_poll_duration_ms,
        fast_poll_interval_ms=options.fast_poll_interval_ms,
        initial_delay_ms=options.initial_delay_ms,
        max_delay_ms=options.max_delay_ms,
        backoff_multiplier=options.backoff_multiplier,
        jitter_fraction=options.jitter_fraction,
    )

    start_time = time.time() * 1000  # Convert to milliseconds

    while True:
        result = retrieve()

        if is_terminal(result):
            return result

        elapsed_ms = (time.time() * 1000) - start_time

        # Only check timeout if max_wait_ms is set
        if max_wait_ms is not None and elapsed_ms >= max_wait_ms:
            raise PollingTimeoutError(
                f"Polling timed out after {int(elapsed_ms)}ms (max: {max_wait_ms}ms)",
                int(elapsed_ms),
                max_wait_ms,
            )

        delay = calculate_hybrid_delay(elapsed_ms, hybrid_options)

        # If timeout is set, don't wait longer than remaining time
        if max_wait_ms is not None:
            remaining_ms = max_wait_ms - elapsed_ms
            actual_delay = min(delay, remaining_ms)
        else:
            actual_delay = delay

        time.sleep(actual_delay / 1000)  # Convert to seconds for time.sleep


async def poll_until_done_async(
    retrieve: Callable[[], Awaitable[T]],
    is_terminal: Callable[[T], bool],
    options: Optional[PollingOptions] = None,
) -> T:
    """
    Polls a retrieve function until a terminal condition is met (asynchronous version).

    Uses a hybrid polling strategy: fast polling at fixed intervals for an initial
    period, then exponential backoff with proportional jitter. This provides low
    latency for quick operations while still reducing server load for longer ones.

    Default behavior:
    - Fast phase: Poll every 1 second for the first 30 seconds
    - Backoff phase: Exponential backoff with 1.15x multiplier, max 30 second delay

    Args:
        retrieve: Async function that fetches the current state
        is_terminal: Predicate that returns True when polling should stop
        options: Polling configuration options

    Returns:
        The final result when is_terminal returns True

    Raises:
        PollingTimeoutError: If max_wait_ms is set and exceeded

    Example:
        # Default hybrid polling
        result = await poll_until_done_async(
            retrieve=lambda: client.extract_runs.retrieve(run_id),
            is_terminal=lambda res: res.extract_run.status != "PROCESSING"
        )

        # Pure exponential backoff (disable fast polling phase)
        result = await poll_until_done_async(
            retrieve=lambda: client.extract_runs.retrieve(run_id),
            is_terminal=lambda res: res.extract_run.status != "PROCESSING",
            options=PollingOptions(fast_poll_duration_ms=0)
        )
    """
    if options is None:
        options = PollingOptions()

    max_wait_ms = options.max_wait_ms
    hybrid_options = HybridDelayOptions(
        fast_poll_duration_ms=options.fast_poll_duration_ms,
        fast_poll_interval_ms=options.fast_poll_interval_ms,
        initial_delay_ms=options.initial_delay_ms,
        max_delay_ms=options.max_delay_ms,
        backoff_multiplier=options.backoff_multiplier,
        jitter_fraction=options.jitter_fraction,
    )

    start_time = time.time() * 1000  # Convert to milliseconds

    while True:
        result = await retrieve()

        if is_terminal(result):
            return result

        elapsed_ms = (time.time() * 1000) - start_time

        # Only check timeout if max_wait_ms is set
        if max_wait_ms is not None and elapsed_ms >= max_wait_ms:
            raise PollingTimeoutError(
                f"Polling timed out after {int(elapsed_ms)}ms (max: {max_wait_ms}ms)",
                int(elapsed_ms),
                max_wait_ms,
            )

        delay = calculate_hybrid_delay(elapsed_ms, hybrid_options)

        # If timeout is set, don't wait longer than remaining time
        if max_wait_ms is not None:
            remaining_ms = max_wait_ms - elapsed_ms
            actual_delay = min(delay, remaining_ms)
        else:
            actual_delay = delay

        await asyncio.sleep(actual_delay / 1000)  # Convert to seconds for asyncio.sleep



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.edit_run_status import EditRunStatus
from .edit_config import EditConfigParams
from .edit_run_metrics import EditRunMetricsParams
from .edit_run_output import EditRunOutputParams
from .file_summary import FileSummaryParams
from .run_usage import RunUsageParams


class EditRunParams(typing_extensions.TypedDict):
    """
    Edit run object.
    """

    object: typing.Literal["edit_run"]
    """
    The type of object. Will always be `"edit_run"`.
    """

    id: str
    """
    A unique identifier for the edit run.
    
    Example: `"edr_xK9mLPqRtN3vS8wF5hB2cQ"`
    """

    file: FileSummaryParams
    """
    The input file that was submitted for editing.
    """

    status: EditRunStatus
    """
    The status of the edit run:
    * `"PROCESSING"` - The file is still being processed
    * `"PROCESSED"` - The file was successfully edited
    * `"FAILED"` - The editing failed (see `failureReason` for details)
    """

    failure_reason: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="failureReason")]
    """
    The reason for failure.
    
    **Availability:** Present when `status` is `"FAILED"`.
    
    Possible values include:
    * `UNABLE_TO_DOWNLOAD_FILE` - Failed to load the requested file
    * `FILE_TYPE_NOT_SUPPORTED` - File type not supported. Edit runs currently require a PDF
    * `FILE_SIZE_TOO_LARGE` - The file exceeds the maximum allowed size
    * `CORRUPT_FILE` - The file appears to be corrupted and cannot be edited
    * `FIELD_DETECTION_ERROR` - An error occurred during field detection
    * `PASSWORD_PROTECTED_FILE` - The file is password protected and cannot be edited
    * `FAILED_TO_CONVERT_TO_PDF` - The file could not be converted to PDF for processing
    * `INTERNAL_ERROR` - An unexpected internal error occurred
    * `INVALID_OPTIONS` - The provided configuration options are invalid
    * `EMPTY_SCHEMA` - No schema was provided and no fields could be detected
    * `OUT_OF_CREDITS` - Insufficient credits to process the file
    
    **Note:** Additional failure reasons may be added in the future. Your integration should handle unknown values gracefully.
    """

    failure_message: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="failureMessage")]
    """
    A human-readable description of the failure.
    
    **Availability:** Present when `status` is `"FAILED"`.
    """

    config: EditConfigParams
    """
    The configuration used for this edit run, including any default values that were applied.
    """

    output: typing.Optional[EditRunOutputParams]
    """
    The output of the edit run.
    
    **Availability:** Present when `status` is `"PROCESSED"`.
    """

    metrics: typing.Optional[EditRunMetricsParams]
    """
    Metrics about the editing process.
    
    **Availability:** Present when `status` is `"PROCESSED"`.
    """

    usage: typing.Optional[RunUsageParams]
    """
    Usage credits consumed by this run.
    
    **Availability:** Present when `status` is `"PROCESSED"`, the run was created after October 7, 2025, and the customer is on the current billing system.
    """



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from .parent_split import ParentSplitParams


class FileMetadataParams(typing_extensions.TypedDict):
    page_count: typing_extensions.NotRequired[typing_extensions.Annotated[float, FieldMetadata(alias="pageCount")]]
    """
    The number of pages in the file. This is only set for PDF/DOCX files.
    """

    parent_split: typing_extensions.NotRequired[
        typing_extensions.Annotated[ParentSplitParams, FieldMetadata(alias="parentSplit")]
    ]



# This file was auto-generated by Fern from our API Definition.

import typing

from .parse_result import ParseResultParams
from .parse_step_run_step import ParseStepRunStepParams
from .step_run_base import StepRunBaseParams


class ParseStepRunParams(StepRunBaseParams):
    step: ParseStepRunStepParams
    result: typing.Optional[ParseResultParams]
    """
    The result of this parse step. Currently, `result` is always present for returned step runs. It is nullable to allow for future support of returning step runs with non-successful statuses.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
from ...core.serialization import FieldMetadata
from ...core.unchecked_base_model import UncheckedBaseModel
from ...types.next_page_token import NextPageToken
from ...types.workflow_run_summary import WorkflowRunSummary


class WorkflowRunsListResponse(UncheckedBaseModel):
    object: typing.Literal["list"] = "list"
    data: typing.List[WorkflowRunSummary]
    next_page_token: typing_extensions.Annotated[
        typing.Optional[NextPageToken], FieldMetadata(alias="nextPageToken")
    ] = pydantic.Field(alias="nextPageToken", default=None)

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class ProvidedSplitOutputSplitsItem(UncheckedBaseModel):
    classification_id: typing_extensions.Annotated[str, FieldMetadata(alias="classificationId")] = pydantic.Field(
        alias="classificationId"
    )
    """
    ID of the classification type (defined in the splitter config)
    """

    type: str = pydantic.Field()
    """
    The type of the split document (defined in the splitter config), corresponds to the classificationId
    """

    start_page: typing_extensions.Annotated[int, FieldMetadata(alias="startPage")] = pydantic.Field(alias="startPage")
    """
    The start page of the split document
    """

    end_page: typing_extensions.Annotated[int, FieldMetadata(alias="endPage")] = pydantic.Field(alias="endPage")
    """
    The end page of the split document
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.json_object import JsonObject
from ..types.legacy_processor_run_type import LegacyProcessorRunType
from ..types.legacy_processor_status import LegacyProcessorStatus
from .file import FileParams
from .legacy_document_processor_run_credits import LegacyDocumentProcessorRunCreditsParams
from .legacy_extraction_output_edits import LegacyExtractionOutputEditsParams
from .legacy_processor_output import LegacyProcessorOutputParams
from .legacy_processor_run_config import LegacyProcessorRunConfigParams
from .legacy_processor_run_merged_processors_item import LegacyProcessorRunMergedProcessorsItemParams


class LegacyProcessorRunParams(typing_extensions.TypedDict):
    object: str
    """
    The type of response. In this case, it will always be `"document_processor_run"`.
    """

    id: str
    """
    The unique identifier for this processor run.
    
    Example: `"exr_Xj8mK2pL9nR4vT7qY5wZ"`
    """

    processor_id: typing_extensions.Annotated[str, FieldMetadata(alias="processorId")]
    """
    The ID of the processor used for this run.
    
    Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`
    """

    processor_version_id: typing_extensions.Annotated[str, FieldMetadata(alias="processorVersionId")]
    """
    The ID of the specific processor version used.
    """

    processor_name: typing_extensions.Annotated[str, FieldMetadata(alias="processorName")]
    """
    The name of the processor.
    
    Example: `"Invoice Processor"`
    """

    status: LegacyProcessorStatus
    output: LegacyProcessorOutputParams
    """
    The final output, either reviewed or initial.
    
    Conforms to the shape of output types and depends on the processor type and configuration shape.
    """

    failure_reason: typing_extensions.NotRequired[
        typing_extensions.Annotated[str, FieldMetadata(alias="failureReason")]
    ]
    """
    If the run failed, indicates the reason for failure.
    """

    failure_message: typing_extensions.NotRequired[
        typing_extensions.Annotated[str, FieldMetadata(alias="failureMessage")]
    ]
    """
    If the run failed, provides a detailed message about the failure.
    """

    metadata: typing_extensions.NotRequired[JsonObject]
    """
    Any metadata that was provided when creating the processor run.
    """

    reviewed: bool
    """
    Indicates whether the run has been reviewed.
    """

    edited: bool
    """
    Indicates whether the run results have been edited.
    """

    edits: typing.Dict[str, LegacyExtractionOutputEditsParams]
    type: LegacyProcessorRunType
    """
    The type of processor:
    * `"CLASSIFY"` - Classifies documents into categories
    * `"EXTRACT"` - Extracts structured data from documents
    * `"SPLITTER"` - Splits documents into multiple parts
    """

    config: LegacyProcessorRunConfigParams
    """
    The configuration used for this processor run. The type of configuration will match the processor type.
    """

    initial_output: typing_extensions.NotRequired[
        typing_extensions.Annotated[LegacyProcessorOutputParams, FieldMetadata(alias="initialOutput")]
    ]
    """
    The initial output from the processor run. The type of output will match the processor type.
    """

    reviewed_output: typing_extensions.NotRequired[
        typing_extensions.Annotated[LegacyProcessorOutputParams, FieldMetadata(alias="reviewedOutput")]
    ]
    """
    The output after review, if any.
    """

    files: typing.Sequence[FileParams]
    """
    Details of the processed files.
    
    If this was a file generated from a splitter processor, this will be the sub file.
    
    See the File object for more details.
    """

    merged_processors: typing_extensions.Annotated[
        typing.Sequence[LegacyProcessorRunMergedProcessorsItemParams], FieldMetadata(alias="mergedProcessors")
    ]
    """
    An array of processors that were merged to create this output. Will be an empty array unless this output was the result of a MergeExtraction step in a workflow.
    """

    url: str
    """
    The URL to view the processor run.
    """

    usage: typing_extensions.NotRequired[LegacyDocumentProcessorRunCreditsParams]



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..types.json_object import JsonObject


class ProvidedExtractOutputParams(typing_extensions.TypedDict):
    """
    The expected extraction output.

    **Important:** Make sure to nest the JSON object conforming to the schema in a `value` object, and include all properties defined in the schema.
    """

    value: typing_extensions.NotRequired[JsonObject]
    """
    The expected extraction output, provided as a JSON object that conforms to the schema defined in the extractor config
    """



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .created_at import CreatedAt
from .extractor_version import ExtractorVersion
from .updated_at import UpdatedAt


class Extractor(UncheckedBaseModel):
    object: typing.Literal["extractor"] = pydantic.Field(default="extractor")
    """
    The type of object. Will always be `"extractor"`.
    """

    id: str = pydantic.Field()
    """
    The ID of the extractor.
    
    Example: `"ex_Xj8mK2pL9nR4vT7qY5wZ"`
    """

    name: str = pydantic.Field()
    """
    The name of the extractor.
    
    Example: `"Invoice Extractor"`
    """

    created_at: typing_extensions.Annotated[CreatedAt, FieldMetadata(alias="createdAt")] = pydantic.Field(
        alias="createdAt"
    )
    updated_at: typing_extensions.Annotated[UpdatedAt, FieldMetadata(alias="updatedAt")] = pydantic.Field(
        alias="updatedAt"
    )
    draft_version: typing_extensions.Annotated[ExtractorVersion, FieldMetadata(alias="draftVersion")] = pydantic.Field(
        alias="draftVersion"
    )
    """
    The draft version of the extractor. This is the editable version in the Extend dashboard.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(Extractor)



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata


class BatchProcessorRunMetricsParams(typing_extensions.TypedDict):
    num_files: typing_extensions.NotRequired[typing_extensions.Annotated[float, FieldMetadata(alias="numFiles")]]
    """
    The total number of files processed in this batch run
    """

    num_pages: typing_extensions.NotRequired[typing_extensions.Annotated[float, FieldMetadata(alias="numPages")]]
    """
    The total number of pages processed in this batch run
    """



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .processor_create_request_config import (
        ProcessorCreateRequestConfig,
        ProcessorCreateRequestConfig_Classify,
        ProcessorCreateRequestConfig_Extract,
        ProcessorCreateRequestConfig_Splitter,
    )
    from .processor_create_response import ProcessorCreateResponse
    from .processor_list_request_sort_by import ProcessorListRequestSortBy
    from .processor_list_request_sort_dir import ProcessorListRequestSortDir
    from .processor_update_request_config import (
        ProcessorUpdateRequestConfig,
        ProcessorUpdateRequestConfig_Classify,
        ProcessorUpdateRequestConfig_Extract,
        ProcessorUpdateRequestConfig_Splitter,
    )
    from .processor_update_response import ProcessorUpdateResponse
_dynamic_imports: typing.Dict[str, str] = {
    "ProcessorCreateRequestConfig": ".processor_create_request_config",
    "ProcessorCreateRequestConfig_Classify": ".processor_create_request_config",
    "ProcessorCreateRequestConfig_Extract": ".processor_create_request_config",
    "ProcessorCreateRequestConfig_Splitter": ".processor_create_request_config",
    "ProcessorCreateResponse": ".processor_create_response",
    "ProcessorListRequestSortBy": ".processor_list_request_sort_by",
    "ProcessorListRequestSortDir": ".processor_list_request_sort_dir",
    "ProcessorUpdateRequestConfig": ".processor_update_request_config",
    "ProcessorUpdateRequestConfig_Classify": ".processor_update_request_config",
    "ProcessorUpdateRequestConfig_Extract": ".processor_update_request_config",
    "ProcessorUpdateRequestConfig_Splitter": ".processor_update_request_config",
    "ProcessorUpdateResponse": ".processor_update_response",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "ProcessorCreateRequestConfig",
    "ProcessorCreateRequestConfig_Classify",
    "ProcessorCreateRequestConfig_Extract",
    "ProcessorCreateRequestConfig_Splitter",
    "ProcessorCreateResponse",
    "ProcessorListRequestSortBy",
    "ProcessorListRequestSortDir",
    "ProcessorUpdateRequestConfig",
    "ProcessorUpdateRequestConfig_Classify",
    "ProcessorUpdateRequestConfig_Extract",
    "ProcessorUpdateRequestConfig_Splitter",
    "ProcessorUpdateResponse",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .created_at import CreatedAt
from .file_summary import FileSummary
from .processor_run_status import ProcessorRunStatus
from .run_metadata import RunMetadata
from .run_usage import RunUsage
from .splitter_summary import SplitterSummary
from .splitter_version_summary import SplitterVersionSummary
from .updated_at import UpdatedAt


class SplitRunSummary(UncheckedBaseModel):
    """
    Summary representation of a split run.
    """

    object: typing.Literal["split_run"] = pydantic.Field(default="split_run")
    """
    The type of object. Will always be `"split_run"`.
    """

    id: str = pydantic.Field()
    """
    The unique identifier for this split run.
    """

    splitter: typing.Optional[SplitterSummary] = pydantic.Field(default=None)
    """
    The splitter that was used for this run.
    
    **Availability:** Present when a splitter reference was provided. Not present when using inline `config`.
    """

    splitter_version: typing_extensions.Annotated[
        typing.Optional[SplitterVersionSummary], FieldMetadata(alias="splitterVersion")
    ] = pydantic.Field(alias="splitterVersion", default=None)
    """
    The version of the splitter that was used for this run.
    
    **Availability:** Present when a splitter reference was provided. Not present when using inline `config`.
    """

    status: ProcessorRunStatus
    failure_reason: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="failureReason")] = (
        pydantic.Field(alias="failureReason", default=None)
    )
    """
    The reason for failure.
    
    **Availability:** Present when `status` is `"FAILED"`.
    """

    failure_message: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="failureMessage")] = (
        pydantic.Field(alias="failureMessage", default=None)
    )
    """
    A detailed message about the failure.
    
    **Availability:** Present when `status` is `"FAILED"`.
    """

    metadata: typing.Optional[RunMetadata] = pydantic.Field(default=None)
    """
    Any metadata that was provided when creating the split run.
    
    **Availability:** Present when metadata was provided during creation.
    """

    reviewed: bool = pydantic.Field()
    """
    Indicates whether the run has been reviewed by a human.
    """

    edited: bool = pydantic.Field()
    """
    Indicates whether the run results have been edited during review.
    """

    file: FileSummary = pydantic.Field()
    """
    The file that was processed.
    """

    parse_run_id: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="parseRunId")] = pydantic.Field(
        alias="parseRunId", default=None
    )
    """
    The ID of the parse run that was used for this split run.
    
    **Availability:** Present when a parse run was created.
    """

    dashboard_url: typing_extensions.Annotated[str, FieldMetadata(alias="dashboardUrl")] = pydantic.Field(
        alias="dashboardUrl"
    )
    """
    The URL to view the split run in the Extend dashboard.
    """

    usage: typing.Optional[RunUsage] = pydantic.Field(default=None)
    """
    Usage credits consumed by this run.
    
    **Availability:** Present when `status` is `"PROCESSED"`.
    """

    created_at: typing_extensions.Annotated[CreatedAt, FieldMetadata(alias="createdAt")] = pydantic.Field(
        alias="createdAt"
    )
    updated_at: typing_extensions.Annotated[UpdatedAt, FieldMetadata(alias="updatedAt")] = pydantic.Field(
        alias="updatedAt"
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from .rule_validation_result_rules_item import RuleValidationResultRulesItemParams


class RuleValidationResultParams(typing_extensions.TypedDict):
    """
    The result of a rule validation step.
    """

    rules: typing.Sequence[RuleValidationResultRulesItemParams]
    """
    The list of validation rules and their results.
    """

    all_passed: typing_extensions.Annotated[bool, FieldMetadata(alias="allPassed")]
    """
    Indicates whether all validation rules passed.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class WorkflowParams(typing_extensions.TypedDict):
    object: typing.Literal["workflow"]
    """
    The type of object. In this case, it will always be `"workflow"`.
    """

    id: str
    """
    The ID of the workflow.
    
    Example: `"workflow_BMlfq_yWM3sT-ZzvCnA3f"`
    """

    name: str
    """
    The name of the workflow.
    
    Example: `"Invoice Processing"`
    """



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from .legacy_provided_splitter_output_splits_item import LegacyProvidedSplitterOutputSplitsItemParams


class LegacyProvidedSplitterOutputParams(typing_extensions.TypedDict):
    splits: typing.Sequence[LegacyProvidedSplitterOutputSplitsItemParams]



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ...core.serialization import FieldMetadata
from ...requests.legacy_batch_processor_run import LegacyBatchProcessorRunParams


class BatchProcessorRunGetResponseParams(typing_extensions.TypedDict):
    success: bool
    batch_processor_run: typing_extensions.Annotated[
        LegacyBatchProcessorRunParams, FieldMetadata(alias="batchProcessorRun")
    ]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class WebhookSubscriptionEventType(enum.StrEnum):
    """
    Event types available for resource-scoped webhook subscriptions. The valid subset depends on the `resourceType`:

    - **extractor**: `extract_run.processed`, `extract_run.failed`
    - **classifier**: `classify_run.processed`, `classify_run.failed`
    - **splitter**: `split_run.processed`, `split_run.failed`
    - **workflow**: `workflow_run.completed`, `workflow_run.failed`, `workflow_run.needs_review`, `workflow_run.rejected`, `workflow_run.cancelled`, `workflow_run.step_run.processed`
    """

    EXTRACT_RUN_PROCESSED = "extract_run.processed"
    EXTRACT_RUN_FAILED = "extract_run.failed"
    CLASSIFY_RUN_PROCESSED = "classify_run.processed"
    CLASSIFY_RUN_FAILED = "classify_run.failed"
    SPLIT_RUN_PROCESSED = "split_run.processed"
    SPLIT_RUN_FAILED = "split_run.failed"
    WORKFLOW_RUN_COMPLETED = "workflow_run.completed"
    WORKFLOW_RUN_FAILED = "workflow_run.failed"
    WORKFLOW_RUN_NEEDS_REVIEW = "workflow_run.needs_review"
    WORKFLOW_RUN_REJECTED = "workflow_run.rejected"
    WORKFLOW_RUN_CANCELLED = "workflow_run.cancelled"
    WORKFLOW_RUN_STEP_RUN_PROCESSED = "workflow_run.step_run.processed"
    _UNKNOWN = "__WEBHOOKSUBSCRIPTIONEVENTTYPE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "WebhookSubscriptionEventType":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        extract_run_processed: typing.Callable[[], T_Result],
        extract_run_failed: typing.Callable[[], T_Result],
        classify_run_processed: typing.Callable[[], T_Result],
        classify_run_failed: typing.Callable[[], T_Result],
        split_run_processed: typing.Callable[[], T_Result],
        split_run_failed: typing.Callable[[], T_Result],
        workflow_run_completed: typing.Callable[[], T_Result],
        workflow_run_failed: typing.Callable[[], T_Result],
        workflow_run_needs_review: typing.Callable[[], T_Result],
        workflow_run_rejected: typing.Callable[[], T_Result],
        workflow_run_cancelled: typing.Callable[[], T_Result],
        workflow_run_step_run_processed: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is WebhookSubscriptionEventType.EXTRACT_RUN_PROCESSED:
            return extract_run_processed()
        if self is WebhookSubscriptionEventType.EXTRACT_RUN_FAILED:
            return extract_run_failed()
        if self is WebhookSubscriptionEventType.CLASSIFY_RUN_PROCESSED:
            return classify_run_processed()
        if self is WebhookSubscriptionEventType.CLASSIFY_RUN_FAILED:
            return classify_run_failed()
        if self is WebhookSubscriptionEventType.SPLIT_RUN_PROCESSED:
            return split_run_processed()
        if self is WebhookSubscriptionEventType.SPLIT_RUN_FAILED:
            return split_run_failed()
        if self is WebhookSubscriptionEventType.WORKFLOW_RUN_COMPLETED:
            return workflow_run_completed()
        if self is WebhookSubscriptionEventType.WORKFLOW_RUN_FAILED:
            return workflow_run_failed()
        if self is WebhookSubscriptionEventType.WORKFLOW_RUN_NEEDS_REVIEW:
            return workflow_run_needs_review()
        if self is WebhookSubscriptionEventType.WORKFLOW_RUN_REJECTED:
            return workflow_run_rejected()
        if self is WebhookSubscriptionEventType.WORKFLOW_RUN_CANCELLED:
            return workflow_run_cancelled()
        if self is WebhookSubscriptionEventType.WORKFLOW_RUN_STEP_RUN_PROCESSED:
            return workflow_run_step_run_processed()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class ParentSplit(UncheckedBaseModel):
    """
    The split metadata details for a derivative file.

    **Availability:** Only included if this file is a derivative of another file, for instance if it was created via a Splitter in a workflow.
    """

    id: str = pydantic.Field()
    """
    The ID of the split.
    """

    type: str = pydantic.Field()
    """
    The type of the split.
    """

    identifier: str = pydantic.Field()
    """
    The identifier of the split.
    """

    start_page: typing_extensions.Annotated[int, FieldMetadata(alias="startPage")] = pydantic.Field(alias="startPage")
    """
    The start page of the split.
    """

    end_page: typing_extensions.Annotated[int, FieldMetadata(alias="endPage")] = pydantic.Field(alias="endPage")
    """
    The end page of the split.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .edit_config import EditConfig
from .edit_run_metrics import EditRunMetrics
from .edit_run_output import EditRunOutput
from .edit_run_status import EditRunStatus
from .file_summary import FileSummary
from .run_usage import RunUsage


class EditRun(UncheckedBaseModel):
    """
    Edit run object.
    """

    object: typing.Literal["edit_run"] = pydantic.Field(default="edit_run")
    """
    The type of object. Will always be `"edit_run"`.
    """

    id: str = pydantic.Field()
    """
    A unique identifier for the edit run.
    
    Example: `"edr_xK9mLPqRtN3vS8wF5hB2cQ"`
    """

    file: FileSummary = pydantic.Field()
    """
    The input file that was submitted for editing.
    """

    status: EditRunStatus = pydantic.Field()
    """
    The status of the edit run:
    * `"PROCESSING"` - The file is still being processed
    * `"PROCESSED"` - The file was successfully edited
    * `"FAILED"` - The editing failed (see `failureReason` for details)
    """

    failure_reason: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="failureReason")] = (
        pydantic.Field(alias="failureReason", default=None)
    )
    """
    The reason for failure.
    
    **Availability:** Present when `status` is `"FAILED"`.
    
    Possible values include:
    * `UNABLE_TO_DOWNLOAD_FILE` - Failed to load the requested file
    * `FILE_TYPE_NOT_SUPPORTED` - File type not supported. Edit runs currently require a PDF
    * `FILE_SIZE_TOO_LARGE` - The file exceeds the maximum allowed size
    * `CORRUPT_FILE` - The file appears to be corrupted and cannot be edited
    * `FIELD_DETECTION_ERROR` - An error occurred during field detection
    * `PASSWORD_PROTECTED_FILE` - The file is password protected and cannot be edited
    * `FAILED_TO_CONVERT_TO_PDF` - The file could not be converted to PDF for processing
    * `INTERNAL_ERROR` - An unexpected internal error occurred
    * `INVALID_OPTIONS` - The provided configuration options are invalid
    * `EMPTY_SCHEMA` - No schema was provided and no fields could be detected
    * `OUT_OF_CREDITS` - Insufficient credits to process the file
    
    **Note:** Additional failure reasons may be added in the future. Your integration should handle unknown values gracefully.
    """

    failure_message: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="failureMessage")] = (
        pydantic.Field(alias="failureMessage", default=None)
    )
    """
    A human-readable description of the failure.
    
    **Availability:** Present when `status` is `"FAILED"`.
    """

    config: EditConfig = pydantic.Field()
    """
    The configuration used for this edit run, including any default values that were applied.
    """

    output: typing.Optional[EditRunOutput] = pydantic.Field(default=None)
    """
    The output of the edit run.
    
    **Availability:** Present when `status` is `"PROCESSED"`.
    """

    metrics: typing.Optional[EditRunMetrics] = pydantic.Field(default=None)
    """
    Metrics about the editing process.
    
    **Availability:** Present when `status` is `"PROCESSED"`.
    """

    usage: typing.Optional[RunUsage] = pydantic.Field(default=None)
    """
    Usage credits consumed by this run.
    
    **Availability:** Present when `status` is `"PROCESSED"`, the run was created after October 7, 2025, and the customer is on the current billing system.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(EditRun)
